@@ -1,26 +1,29 @@
 /*****************************************************************************
  * Copyright (C) 2002 Shie Erlich <erlich@users.sourceforge.net>             *
  * Copyright (C) 2002 Rafi Yanai <yanai@users.sourceforge.net>               *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
  *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
  * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
+ * the Free Software Foundation, either version 2 of the License, or         *
  * (at your option) any later version.                                       *
  *                                                                           *
- * This package is distributed in the hope that it will be useful,           *
+ * Krusader is distributed in the hope that it will be useful,               *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
  * GNU General Public License for more details.                              *
  *                                                                           *
  * You should have received a copy of the GNU General Public License         *
- * along with this package; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
  *****************************************************************************/
 
 #include "krbookmarkhandler.h"
 #include "kraddbookmarkdlg.h"
 
 #include "../krglobal.h"
+#include "../icon.h"
 #include "../krslots.h"
 #include "../kractions.h"
 #include "../krmainwindow.h"
@@ -34,13 +37,14 @@
 #include <QFile>
 #include <QEvent>
 #include <QStandardPaths>
+#include <QDebug>
+#include <QTimer>
 // QtGui
 #include <QMouseEvent>
 #include <QCursor>
 
 #include <KConfigCore/KSharedConfig>
 #include <KI18n/KLocalizedString>
-#include <KIconThemes/KIconLoader>
 #include <KWidgetsAddons/KMessageBox>
 #include <KXmlGui/KActionCollection>
 #include <KBookmarks/KBookmarkManager>
@@ -51,8 +55,15 @@
 #define BOOKMARKS_FILE "krusader/krbookmarks.xml"
 #define CONNECT_BM(X) { disconnect(X, SIGNAL(activated(QUrl)), 0, 0); connect(X, SIGNAL(activated(QUrl)), this, SLOT(slotActivated(QUrl))); }
 
-KrBookmarkHandler::KrBookmarkHandler(KrMainWindow *mainWindow) : QObject(mainWindow->widget()),
-        _mainWindow(mainWindow), _middleClick(false), _mainBookmarkPopup(0), _specialBookmarks()
+KrBookmarkHandler::KrBookmarkHandler(KrMainWindow *mainWindow) :
+    QObject(mainWindow->widget()),
+    _mainWindow(mainWindow),
+    _middleClick(false),
+    _mainBookmarkPopup(0),
+    _specialBookmarks(),
+    _quickSearchAction(nullptr),
+    _quickSearchBar(nullptr),
+    _quickSearchMenu(nullptr)
 {
     // create our own action collection and make the shortcuts apply only to parent
     _privateCollection = new KActionCollection(this);
@@ -65,10 +76,23 @@ KrBookmarkHandler::KrBookmarkHandler(KrMainWindow *mainWindow) : QObject(mainWin
     // load bookmarks
     importFromFile();
 
-    // hack
+    // create bookmark manager
     QString filename = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + BOOKMARKS_FILE;
     manager = KBookmarkManager::managerForFile(filename, QStringLiteral("krusader"));
     connect(manager, SIGNAL(changed(QString,QString)), this, SLOT(bookmarksChanged(QString,QString)));
+
+    // create the quick search bar and action
+    _quickSearchAction = new QWidgetAction(this);
+    _quickSearchBar = new QLineEdit();
+    _quickSearchBar->setPlaceholderText(i18n("Type to search..."));
+    _quickSearchAction->setDefaultWidget(_quickSearchBar);  // ownership of the bar is transferred to the action
+    _quickSearchAction->setEnabled(false);
+    _setQuickSearchText("");
+
+    // fill a dummy menu to properly init actions (allows toolbar bookmark buttons to work properly)
+    auto menu = new QMenu(mainWindow->widget());
+    populate(menu);
+    menu->deleteLater();
 }
 
 KrBookmarkHandler::~KrBookmarkHandler()
@@ -208,7 +232,7 @@ void KrBookmarkHandler::exportToFile()
 
 bool KrBookmarkHandler::importFromFileBookmark(QDomElement &e, KrBookmark *parent, QString path, QString *errorMsg)
 {
-    QString url, name, icon;
+    QString url, name, iconName;
     // verify tag
     if (e.tagName() != "bookmark") {
         *errorMsg = i18n("%1 instead of %2", e.tagName(), QLatin1String("bookmark"));
@@ -227,14 +251,17 @@ bool KrBookmarkHandler::importFromFileBookmark(QDomElement &e, KrBookmark *paren
     } else name = te.text();
     // do we have an icon?
     if (e.hasAttribute("icon")) {
-        icon = e.attribute("icon");
+        iconName = e.attribute("icon");
     }
     // ok: got name and url, let's add a bookmark
     KrBookmark *bm = KrBookmark::getExistingBookmark(path + name, _collection);
     if (!bm) {
-        bm = new KrBookmark(name, QUrl(url), _collection, icon, path + name);
-        parent->children().append(bm);
+        bm = new KrBookmark(name, QUrl(url), _collection, iconName, path + name);
+    } else {
+        bm->setURL(QUrl(url));
+        bm->setIconName(iconName);
     }
+    parent->children().append(bm);
 
     return true;
 }
@@ -274,7 +301,7 @@ bool KrBookmarkHandler::importFromFileFolder(QDomNode &first, KrBookmark *parent
 
 void KrBookmarkHandler::importFromFile()
 {
-    clearBookmarks(_root);
+    clearBookmarks(_root, false);
 
     QString filename = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + BOOKMARKS_FILE;
     QFile file(filename);
@@ -307,17 +334,56 @@ BM_SUCCESS:
     file.close();
 }
 
+void KrBookmarkHandler::_setQuickSearchText(const QString &text)
+{
+    bool isEmptyQuickSearchBarVisible = KConfigGroup(krConfig, "Look&Feel").readEntry("Always show search bar", true);
+
+    _quickSearchBar->setText(text);
+
+    auto length = text.length();
+    bool isVisible = isEmptyQuickSearchBarVisible || length > 0;
+    _quickSearchAction->setVisible(isVisible);
+    _quickSearchBar->setVisible(isVisible);
+
+    if (length == 0) {
+        qDebug() << "Bookmark search: reset";
+        _resetActionTextAndHighlighting();
+    } else {
+        qDebug() << "Bookmark search: query =" << text;
+    }
+}
+
+QString KrBookmarkHandler::_quickSearchText() const
+{
+    return _quickSearchBar->text();
+}
+
+void KrBookmarkHandler::_highlightAction(QAction *action, bool isMatched)
+{
+    auto font = action->font();
+    font.setBold(isMatched);
+    action->setFont(font);
+}
+
 void KrBookmarkHandler::populate(QMenu *menu)
 {
+    // removing action from previous menu is necessary
+    // otherwise it won't be displayed in the currently populating menu
+    if (_mainBookmarkPopup) {
+        _mainBookmarkPopup->removeAction(_quickSearchAction);
+    }
     _mainBookmarkPopup = menu;
     menu->clear();
     _specialBookmarks.clear();
     buildMenu(_root, menu);
 }
 
-void KrBookmarkHandler::buildMenu(KrBookmark *parent, QMenu *menu)
+void KrBookmarkHandler::buildMenu(KrBookmark *parent, QMenu *menu, int depth)
 {
-    static int inSecondaryMenu = 0; // used to know if we're on the top menu
+    // add search bar widget to the top of the menu
+    if (depth == 0) {
+        menu->addAction(_quickSearchAction);
+    }
 
     // run the loop twice, in order to put the folders on top. stupid but easy :-)
     // note: this code drops the separators put there by the user
@@ -327,16 +393,14 @@ void KrBookmarkHandler::buildMenu(KrBookmark *parent, QMenu *menu)
 
         if (!bm->isFolder()) continue;
         QMenu *newMenu = new QMenu(menu);
-        newMenu->setIcon(QIcon(krLoader->loadIcon(bm->iconName(), KIconLoader::Small)));
+        newMenu->setIcon(Icon(bm->iconName()));
         newMenu->setTitle(bm->text());
         QAction *menuAction = menu->addMenu(newMenu);
         QVariant v;
         v.setValue<KrBookmark *>(bm);
         menuAction->setData(v);
 
-        ++inSecondaryMenu;
-        buildMenu(bm, newMenu);
-        --inSecondaryMenu;
+        buildMenu(bm, newMenu, depth + 1);
     }
 
     it.toFront();
@@ -351,7 +415,7 @@ void KrBookmarkHandler::buildMenu(KrBookmark *parent, QMenu *menu)
         CONNECT_BM(bm);
     }
 
-    if (!inSecondaryMenu) {
+    if (depth == 0) {
         KConfigGroup group(krConfig, "Private");
         bool hasPopularURLs = group.readEntry("BM Popular URLs", true);
         bool hasTrash       = group.readEntry("BM Trash",        true);
@@ -365,7 +429,7 @@ void KrBookmarkHandler::buildMenu(KrBookmark *parent, QMenu *menu)
             // add the popular links submenu
             QMenu *newMenu = new QMenu(menu);
             newMenu->setTitle(i18n("Popular URLs"));
-            newMenu->setIcon(QIcon(krLoader->loadIcon("folder-bookmark", KIconLoader::Small)));
+            newMenu->setIcon(Icon("folder-bookmark"));
             QAction *bmfAct  = menu->addMenu(newMenu);
             _specialBookmarks.append(bmfAct);
             // add the top 15 urls
@@ -392,7 +456,7 @@ void KrBookmarkHandler::buildMenu(KrBookmark *parent, QMenu *menu)
 
         // do we need to add special bookmarks?
         if (SPECIAL_BOOKMARKS) {
-            if (hasTrash || hasLan || hasVirtualFS || hasJumpback)
+            if (hasTrash || hasLan || hasVirtualFS)
                 menu->addSeparator();
 
             KrBookmark *bm;
@@ -420,22 +484,37 @@ void KrBookmarkHandler::buildMenu(KrBookmark *parent, QMenu *menu)
             }
 
             if (hasJumpback) {
-                // add the jump-back button
-                ListPanelActions *actions = _mainWindow->listPanelActions();
-                menu->addAction(actions->actJumpBack);
-                _specialBookmarks.append(actions->actJumpBack);
                 menu->addSeparator();
-                menu->addAction(actions->actSetJumpBack);
-                _specialBookmarks.append(actions->actSetJumpBack);
+
+                ListPanelActions *actions = _mainWindow->listPanelActions();
+
+                auto slotTriggered = [=] {
+                    if (_mainBookmarkPopup && !_mainBookmarkPopup->isHidden()) {
+                        _mainBookmarkPopup->close();
+                    }
+                };
+                auto addJumpBackAction = [=](bool isSetter) {
+                    auto action = KrBookmark::jumpBackAction(_privateCollection, isSetter, actions);
+                    if (action) {
+                        menu->addAction(action);
+                        _specialBookmarks.append(action);
+
+                        // disconnecting from this as a receiver is important:
+                        // we don't want to break connections established by KrBookmark::jumpBackAction
+                        disconnect(action, &QAction::triggered, this, nullptr);
+                        connect(action, &QAction::triggered, this, slotTriggered);
+                    }
+                };
+
+                addJumpBackAction(true);
+                addJumpBackAction(false);
             }
         }
 
-        if (!hasJumpback)
-            menu->addSeparator();
-
+        menu->addSeparator();
         menu->addAction(KrActions::actAddBookmark);
         _specialBookmarks.append(KrActions::actAddBookmark);
-        QAction *bmAct = menu->addAction(krLoader->loadIcon("bookmarks", KIconLoader::Small),
+        QAction *bmAct = menu->addAction(Icon("bookmarks"),
                                          i18n("Manage Bookmarks"), manager, SLOT(slotEditBookmarks()));
         _specialBookmarks.append(bmAct);
 
@@ -446,21 +525,22 @@ void KrBookmarkHandler::buildMenu(KrBookmark *parent, QMenu *menu)
     menu->installEventFilter(this);
 }
 
-void KrBookmarkHandler::clearBookmarks(KrBookmark *root)
+void KrBookmarkHandler::clearBookmarks(KrBookmark *root, bool removeBookmarks)
 {
-    QList<KrBookmark *>::iterator it = root->children().begin();
-    while (it != root->children().end()) {
+    for (auto it = root->children().begin(); it != root->children().end(); it = root->children().erase(it)) {
         KrBookmark *bm = *it;
 
-        if (bm->isFolder())
-            clearBookmarks(bm);
-        else {
-            foreach(QWidget *w, bm->associatedWidgets())
-            w->removeAction(bm);
+        if (bm->isFolder()) {
+            clearBookmarks(bm, removeBookmarks);
+            delete bm;
+        } else if (bm->isSeparator()) {
+            delete bm;
+        } else if (removeBookmarks) {
+            foreach (QWidget *w, bm->associatedWidgets()) {
+                w->removeAction(bm);
+            }
             delete bm;
         }
-
-        it = root->children().erase(it);
     }
 }
 
@@ -471,28 +551,173 @@ void KrBookmarkHandler::bookmarksChanged(const QString&, const QString&)
 
 bool KrBookmarkHandler::eventFilter(QObject *obj, QEvent *ev)
 {
-    if (ev->type() == QEvent::MouseButtonRelease) {
-        switch (static_cast<QMouseEvent*>(ev)->button()) {
+    auto eventType = ev->type();
+    QMenu *menu = dynamic_cast<QMenu *>(obj);
+
+    if (eventType == QEvent::Show && menu) {
+        _setQuickSearchText("");
+        _quickSearchMenu = menu;
+        qDebug() << "Bookmark search: menu" << menu << "is shown";
+
+        return QObject::eventFilter(obj, ev);
+    }
+
+    if (eventType == QEvent::Close && menu && _quickSearchMenu) {
+        if (_quickSearchMenu == menu) {
+            qDebug() << "Bookmark search: stopped on menu" << menu;
+            _setQuickSearchText("");
+            _quickSearchMenu = nullptr;
+        } else {
+            qDebug() << "Bookmark search: active action =" << _quickSearchMenu->activeAction();
+
+            // fix automatic deactivation of current action due to spurious close event from submenu
+            auto quickSearchMenu = _quickSearchMenu;
+            auto activeAction = _quickSearchMenu->activeAction();
+            QTimer::singleShot(0, this, [=]() {
+                qDebug() << "Bookmark search: active action =" << quickSearchMenu->activeAction();
+                if (!quickSearchMenu->activeAction() && activeAction) {
+                    quickSearchMenu->setActiveAction(activeAction);
+                    qDebug() << "Bookmark search: restored active action =" << quickSearchMenu->activeAction();
+                }
+            });
+        }
+
+        return QObject::eventFilter(obj, ev);
+    }
+
+    // Having it occur on keypress is consistent with other shortcuts,
+    // such as Ctrl+W and accelerator keys
+    if (eventType == QEvent::KeyPress && menu) {
+        QKeyEvent *kev = static_cast<QKeyEvent *>(ev);
+        QList<QAction *> acts = menu->actions();
+        bool quickSearchStarted = false;
+        bool searchInSpecialItems = KConfigGroup(krConfig, "Look&Feel").readEntry("Search in special items", false);
+
+        if (kev->key() == Qt::Key_Left && kev->modifiers() == Qt::NoModifier) {
+            menu->close();
+            return true;
+        }
+
+        if ((kev->modifiers() != Qt::ShiftModifier &&
+             kev->modifiers() != Qt::NoModifier) ||
+            kev->text().isEmpty()                ||
+            kev->key() == Qt::Key_Delete         ||
+            kev->key() == Qt::Key_Return         ||
+            kev->key() == Qt::Key_Escape) {
+            return QObject::eventFilter(obj, ev);
+        }
+
+        // update quick search text
+        if (kev->key() == Qt::Key_Backspace) {
+            auto newSearchText = _quickSearchText();
+            newSearchText.chop(1);
+            _setQuickSearchText(newSearchText);
+
+            if (_quickSearchText().length() == 0) {
+                return QObject::eventFilter(obj, ev);
+            }
+        } else {
+            quickSearchStarted = _quickSearchText().length() == 0;
+            _setQuickSearchText(_quickSearchText().append(kev->text()));
+        }
+
+        if (quickSearchStarted) {
+            _quickSearchMenu = menu;
+            qDebug() << "Bookmark search: started on menu" << menu;
+        }
+
+        // match actions
+        QAction *matchedAction = nullptr;
+        int nMatches = 0;
+        const Qt::CaseSensitivity matchCase =
+            _quickSearchText() == _quickSearchText().toLower() ? Qt::CaseInsensitive : Qt::CaseSensitive;
+        for (auto act : acts) {
+            if (act->isSeparator() || act->text() == "") {
+                continue;
+            }
+
+            if (!searchInSpecialItems && _specialBookmarks.contains(act)) {
+                continue;
+            }
+
+            if (quickSearchStarted) {
+                // if the first key press is an accelerator key, let the accelerator handler process this event
+                if (act->text().contains('&' + kev->text(), Qt::CaseInsensitive)) {
+                    qDebug() << "Bookmark search: hit accelerator key of" << act;
+                    _setQuickSearchText("");
+                    return QObject::eventFilter(obj, ev);
+                }
+
+                // strip accelerator keys from actions so they don't interfere with the search key press events
+                auto text = act->text();
+                _quickSearchOriginalActionTitles.insert(act, text);
+                act->setText(KLocalizedString::removeAcceleratorMarker(text));
+            }
+
+            // match prefix of the action text to the query
+            if (act->text().left(_quickSearchText().length()).compare(_quickSearchText(), matchCase) == 0) {
+                _highlightAction(act);
+                if (!matchedAction || matchedAction->menu()) {
+                    // Can't highlight menus (see comment below), hopefully pick something we can
+                    matchedAction = act;
+                }
+                nMatches++;
+            } else {
+                _highlightAction(act, false);
+            }
+        }
+
+        if (matchedAction) {
+            qDebug() << "Bookmark search: primary match =" << matchedAction->text() << ", number of matches =" << nMatches;
+        } else {
+            qDebug() << "Bookmark search: no matches";
+        }
+
+        // trigger the matched menu item or set an active item accordingly
+        if (nMatches == 1) {
+            _setQuickSearchText("");
+            if ((bool) matchedAction->menu()) {
+                menu->setActiveAction(matchedAction);
+            } else {
+                matchedAction->activate(QAction::Trigger);
+            }
+        } else if (nMatches > 1) {
+            // Because of a bug submenus cannot be highlighted
+            // https://bugreports.qt.io/browse/QTBUG-939
+            if (!matchedAction->menu()) {
+                menu->setActiveAction(matchedAction);
+            } else {
+                menu->setActiveAction(nullptr);
+            }
+        } else {
+            menu->setActiveAction(nullptr);
+        }
+        return true;
+    }
+
+    if (eventType == QEvent::MouseButtonRelease) {
+        switch (static_cast<QMouseEvent *>(ev)->button()) {
         case Qt::RightButton:
             _middleClick = false;
             if (obj->inherits("QMenu")) {
-                QMenu * menu = static_cast<QMenu*>(obj);
-                QAction * act = menu->actionAt(static_cast<QMouseEvent*>(ev)->pos());
+                QMenu *menu = static_cast<QMenu *>(obj);
+                QAction *act = menu->actionAt(static_cast<QMouseEvent *>(ev)->pos());
 
                 if (obj == _mainBookmarkPopup && _specialBookmarks.contains(act)) {
                     rightClickOnSpecialBookmark();
                     return true;
                 }
 
-                KrBookmark * bm = dynamic_cast<KrBookmark*>(act);
+                KrBookmark *bm = dynamic_cast<KrBookmark *>(act);
                 if (bm != 0) {
                     rightClicked(menu, bm);
                     return true;
                 } else if (act && act->data().canConvert<KrBookmark *>()) {
-                    KrBookmark * bm = act->data().value<KrBookmark *> ();
+                    KrBookmark *bm = act->data().value<KrBookmark *>();
                     rightClicked(menu, bm);
                 }
             }
+            break;
         case Qt::LeftButton:
             _middleClick = false;
             break;
@@ -506,6 +731,18 @@ bool KrBookmarkHandler::eventFilter(QObject *obj, QEvent *ev)
     return QObject::eventFilter(obj, ev);
 }
 
+void KrBookmarkHandler::_resetActionTextAndHighlighting()
+{
+    for (QHash<QAction *, QString>::const_iterator i = _quickSearchOriginalActionTitles.begin();
+         i != _quickSearchOriginalActionTitles.end(); ++i) {
+        QAction *action = i.key();
+        action->setText(i.value());
+        _highlightAction(action, false);
+    }
+
+    _quickSearchOriginalActionTitles.clear();
+}
+
 #define POPULAR_URLS_ID        100100
 #define TRASH_ID               100101
 #define LAN_ID                 100103
@@ -594,13 +831,13 @@ void KrBookmarkHandler::rightClicked(QMenu *menu, KrBookmark * bm)
     QAction * act;
 
     if (!bm->isFolder()) {
-        act = popup.addAction(krLoader->loadIcon("document-open", KIconLoader::Panel), i18n("Open"));
+        act = popup.addAction(Icon("document-open"), i18n("Open"));
         act->setData(QVariant(OPEN_ID));
-        act = popup.addAction(krLoader->loadIcon("tab-new", KIconLoader::Panel), i18n("Open in a new tab"));
+        act = popup.addAction(Icon("tab-new"), i18n("Open in a new tab"));
         act->setData(QVariant(OPEN_NEW_TAB_ID));
         popup.addSeparator();
     }
-    act = popup.addAction(krLoader->loadIcon("edit-delete", KIconLoader::Panel), i18n("Delete"));
+    act = popup.addAction(Icon("edit-delete"), i18n("Delete"));
     act->setData(QVariant(DELETE_ID));
 
     connect(menu, SIGNAL(highlighted(int)), &popup, SLOT(close()));
