@@ -1,25 +1,28 @@
 /*****************************************************************************
  * Copyright (C) 2000 Shie Erlich <erlich@users.sourceforge.net>             *
  * Copyright (C) 2000 Rafi Yanai <yanai@users.sourceforge.net>               *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
  *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
  * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
+ * the Free Software Foundation, either version 2 of the License, or         *
  * (at your option) any later version.                                       *
  *                                                                           *
- * This package is distributed in the hope that it will be useful,           *
+ * Krusader is distributed in the hope that it will be useful,               *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
  * GNU General Public License for more details.                              *
  *                                                                           *
  * You should have received a copy of the GNU General Public License         *
- * along with this package; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
  *****************************************************************************/
 
 #include "krdialogs.h"
 
 // QtCore
+#include <QDebug>
 #include <QDir>
 // QtGui
 #include <QFontMetrics>
@@ -71,14 +74,9 @@ QUrl KChooseDir::get(const QString &text, const QUrl &url, const QUrl &cwd, KFil
 }
 
 KChooseDir::ChooseResult KChooseDir::getCopyDir(const QString &text, const QUrl &url,
-                                                const QUrl &cwd, bool preserveAttrs,
-                                                const QUrl &baseURL)
+                                                const QUrl &cwd)
 {
-    QScopedPointer<KUrlRequesterDlgForCopy> dlg(new KUrlRequesterDlgForCopy(
-        FileSystem::ensureTrailingSlash(url), text, preserveAttrs, krMainWindow, true, baseURL));
-
-    if (!preserveAttrs)
-        dlg->hidePreserveAttrs();
+    QScopedPointer<KUrlRequesterDlgForCopy> dlg(new KUrlRequesterDlgForCopy(url, text, krMainWindow, true));
 
     dlg->urlRequester()->setStartDir(cwd);
     dlg->urlRequester()->setMode(KFile::Directory);
@@ -93,15 +91,12 @@ KChooseDir::ChooseResult KChooseDir::getCopyDir(const QString &text, const QUrl
     ChooseResult result;
     result.url = u;
     result.enqueue = dlg->isQueued();
-    result.preserveAttrs = dlg->preserveAttrs();
-    result.baseURL = dlg->copyDirStructure() ? dlg->baseURL() : QUrl();
     return result;
 }
 
 KUrlRequesterDlgForCopy::KUrlRequesterDlgForCopy(const QUrl &urlName, const QString &_text,
-                                                 bool /*presAttrs*/, QWidget *parent, bool modal,
-                                                 const QUrl &baseURL)
-    : QDialog(parent), baseUrlCombo(0), copyDirStructureCB(0)
+                                                 QWidget *parent, bool modal)
+    : QDialog(parent)
 {
     setWindowModality(modal ? Qt::WindowModal : Qt::NonModal);
 
@@ -113,38 +108,6 @@ KUrlRequesterDlgForCopy::KUrlRequesterDlgForCopy(const QUrl &urlName, const QStr
     urlRequester_ = new KUrlRequester(urlName, this);
     urlRequester_->setMinimumWidth(urlRequester_->sizeHint().width() * 3);
     mainLayout->addWidget(urlRequester_);
-//     preserveAttrsCB = new QCheckBox(i18n("Preserve attributes (only for local targets)"), widget);
-//     preserveAttrsCB->setChecked(presAttrs);
-//     topLayout->addWidget(preserveAttrsCB);
-    if (!baseURL.isEmpty()) {
-        QFrame *line = new QFrame(this);
-        line->setFrameStyle(QFrame::HLine | QFrame::Sunken);
-        mainLayout->addWidget(line);
-        copyDirStructureCB = new QCheckBox(i18n("Keep virtual folder structure"), this);
-        connect(copyDirStructureCB, SIGNAL(toggled(bool)), this, SLOT(slotDirStructCBChanged()));
-        copyDirStructureCB->setChecked(false);
-        mainLayout->addWidget(copyDirStructureCB);
-        QWidget *hboxWidget = new QWidget(this);
-        QHBoxLayout * hbox = new QHBoxLayout(hboxWidget);
-        QLabel * lbl = new QLabel(i18n("Base URL:"),  hboxWidget);
-        hbox->addWidget(lbl);
-
-        baseUrlCombo = new QComboBox(hboxWidget);
-        baseUrlCombo->setMinimumWidth(baseUrlCombo->sizeHint().width() * 3);
-        baseUrlCombo->setEnabled(copyDirStructureCB->isChecked());
-        hbox->addWidget(baseUrlCombo);
-
-        QUrl temp = baseURL, tempOld;
-        do {
-            QString baseURLText = temp.toDisplayString(QUrl::PreferLocalFile);
-            baseUrlCombo->addItem(baseURLText);
-            tempOld = temp;
-            temp = KIO::upUrl(temp);
-        } while (!tempOld.matches(temp, QUrl::StripTrailingSlash));
-        baseUrlCombo->setCurrentIndex(0);
-
-        mainLayout->addWidget(hboxWidget);
-    }
 
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
     mainLayout->addWidget(buttonBox);
@@ -186,35 +149,17 @@ void KUrlRequesterDlgForCopy::slotQueueButtonClicked()
     accept();
 }
 
-
-bool KUrlRequesterDlgForCopy::preserveAttrs()
-{
-//     return preserveAttrsCB->isChecked();
-    return true;
-}
-
-bool KUrlRequesterDlgForCopy::copyDirStructure()
-{
-    if (copyDirStructureCB == 0)
-        return false;
-    return copyDirStructureCB->isChecked();
-}
-
 void KUrlRequesterDlgForCopy::slotTextChanged(const QString & text)
 {
     bool state = !text.trimmed().isEmpty();
     okButton->setEnabled(state);
 }
 
-void KUrlRequesterDlgForCopy::slotDirStructCBChanged()
-{
-    baseUrlCombo->setEnabled(copyDirStructureCB->isChecked());
-}
-
 QUrl KUrlRequesterDlgForCopy::selectedURL() const
 {
     if (result() == QDialog::Accepted) {
         QUrl url = urlRequester_->url();
+        qDebug() << "requester returned URL=" << url.toDisplayString();
         if (url.isValid())
             KRecentDocument::add(url);
         return url;
@@ -227,13 +172,6 @@ KUrlRequester * KUrlRequesterDlgForCopy::urlRequester()
     return urlRequester_;
 }
 
-QUrl KUrlRequesterDlgForCopy::baseURL() const
-{
-    if (baseUrlCombo == 0)
-        return QUrl();
-    return QUrl::fromUserInput(baseUrlCombo->currentText(), QString(), QUrl::AssumeLocalFile);
-}
-
 KRGetDate::KRGetDate(QDate date, QWidget *parent) : QDialog(parent, Qt::MSWindowsFixedSizeDialogHint)
 {
     setWindowModality(Qt::WindowModal);
