@@ -1,20 +1,22 @@
 /*****************************************************************************
  * Copyright (C) 2002 Shie Erlich <erlich@users.sourceforge.net>             *
  * Copyright (C) 2002 Rafi Yanai <yanai@users.sourceforge.net>               *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
  *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
  * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
+ * the Free Software Foundation, either version 2 of the License, or         *
  * (at your option) any later version.                                       *
  *                                                                           *
- * This package is distributed in the hope that it will be useful,           *
+ * Krusader is distributed in the hope that it will be useful,               *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
  * GNU General Public License for more details.                              *
  *                                                                           *
  * You should have received a copy of the GNU General Public License         *
- * along with this package; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
  *****************************************************************************/
 
 #include "krviewer.h"
@@ -36,7 +38,6 @@
 #include <KConfigCore/KSharedConfig>
 #include <KConfigWidgets/KStandardAction>
 #include <KI18n/KLocalizedString>
-#include <KIconThemes/KIconLoader>
 #include <KIOCore/KFileItem>
 #include <KParts/Part>
 #include <KWidgetsAddons/KMessageBox>
@@ -45,7 +46,7 @@
 #include <KXmlGui/KToolBar>
 
 #include "../defaults.h"
-#include "../kicons.h"
+#include "../icon.h"
 #include "panelviewer.h"
 
 #define VIEW_ICON     "document-preview"
@@ -130,19 +131,25 @@ KrViewer::KrViewer(QWidget *parent) :
     quitAction = ac->addAction(KStandardAction::Quit, this, SLOT(close()));
     viewerMenu->addAction(quitAction);
 
+    QList<QKeySequence> shortcuts;
+
     tabCloseAction = ac->addAction("closeTab", this, SLOT(tabCloseRequest()));
     tabCloseAction->setText(i18n("&Close Current Tab"));
-    QList<QKeySequence> shortcuts = KStandardShortcut::close();
+    shortcuts = KStandardShortcut::close();
     shortcuts.append(Qt::Key_Escape);
     ac->setDefaultShortcuts(tabCloseAction, shortcuts);
 
     tabNextAction = ac->addAction("nextTab", this, SLOT(nextTab()));
     tabNextAction->setText(i18n("&Next Tab"));
-    ac->setDefaultShortcuts(tabNextAction, KStandardShortcut::tabNext());
+    shortcuts = KStandardShortcut::tabNext();
+    shortcuts.append(Qt::CTRL + Qt::Key_Tab);  // reenforce QTabWidget shortcut
+    ac->setDefaultShortcuts(tabNextAction, shortcuts);
 
     tabPrevAction = ac->addAction("prevTab", this, SLOT(prevTab()));
     tabPrevAction->setText(i18n("&Previous Tab"));
-    ac->setDefaultShortcuts(tabPrevAction, KStandardShortcut::tabPrev());
+    shortcuts = KStandardShortcut::tabPrev();
+    shortcuts.append(Qt::CTRL + Qt::SHIFT + Qt::Key_Tab);  // reenforce QTabWidget shortcut
+    ac->setDefaultShortcuts(tabPrevAction, shortcuts);
 
 
     tabBar.setTabsClosable(true);
@@ -324,7 +331,7 @@ void KrViewer::edit(QUrl url, Mode mode, int new_window, QWidget * parent)
         proc << cmdArgs << url.toDisplayString(QUrl::PreferLocalFile);
         if (!proc.startDetached())
             KMessageBox::sorry(krMainWindow, i18n("Can not open \"%1\"", editor));
-        return ;
+        return;
     }
 
     KrViewer* viewer = getViewer(new_window);
@@ -373,7 +380,9 @@ void KrViewer::openUrlFinished(PanelViewerBase *pvb, bool success)
                     part->widget()->setFocus();
             }
         }
-    }
+    } else {
+        tabCloseRequest(tabBar.currentIndex(), false);
+      }
 }
 
 void KrViewer::tabChanged(int index)
@@ -396,10 +405,11 @@ void KrViewer::tabChanged(int index)
 void KrViewer::tabCloseRequest(int index, bool force)
 {
     // important to save as returnFocusTo will be cleared at removePart
-    QWidget * returnFocusToThisWidget = returnFocusTo;
+    QWidget *returnFocusToThisWidget = returnFocusTo;
 
-    PanelViewerBase* pvb = static_cast<PanelViewerBase*>(tabBar.widget(index));
-    if (!pvb) return;
+    PanelViewerBase *pvb = static_cast<PanelViewerBase *>(tabBar.widget(index));
+    if (!pvb)
+        return;
 
     if (!force && !pvb->queryClose())
         return;
@@ -426,17 +436,10 @@ void KrViewer::tabCloseRequest(int index, bool force)
         }
 
         QTimer::singleShot(0, this, SLOT(close()));
-
-        return;
     } else if (tabBar.count() == 1) {
-        //no point in detaching only one tab..
+        // no point in detaching only one tab..
         detachAction->setEnabled(false);
     }
-
-    if (returnFocusToThisWidget) {
-        returnFocusToThisWidget->raise();
-        returnFocusToThisWidget->activateWindow();
-    }
 }
 
 void KrViewer::tabCloseRequest()
@@ -656,7 +659,7 @@ QIcon KrViewer::makeTabIcon(PanelViewerBase *pvb)
     else
         iconName = VIEW_ICON;
 
-    return QIcon(krLoader->loadIcon(iconName, KIconLoader::Small));
+    return Icon(iconName);
 }
 
 void KrViewer::addPart(KParts::ReadOnlyPart *part)
