@@ -1,33 +1,22 @@
-/***************************************************************************
-                        kgpanel.cpp  -  description
-                             -------------------
-    copyright            : (C) 2003 by Csaba Karai
-    copyright            : (C) 2010 by Jan Lepper
-    e-mail               : krusader@users.sourceforge.net
-    web site             : http://krusader.sourceforge.net
- ---------------------------------------------------------------------------
-  Description
- ***************************************************************************
-
-  A
-
-     db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-     88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-     88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-     88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-     88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-     YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                                     S o u r c e    F i l e
-
- ***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2010 Jan Lepper <krusader@users.sourceforge.net>            *
+ * Copyright (C) 2010-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #include "kgpanel.h"
 #include "../defaults.h"
@@ -47,13 +36,13 @@
 
 #include "../GUI/krtreewidget.h"
 #include "../Panel/krsearchbar.h"
-#include "../Panel/krselectionmode.h"
-#include "../Panel/krview.h"
-#include "../Panel/krviewfactory.h"
+#include "../Panel/PanelView/krselectionmode.h"
+#include "../Panel/PanelView/krview.h"
+#include "../Panel/PanelView/krviewfactory.h"
 #include "../Panel/krlayoutfactory.h"
 
 enum {
-    PAGE_MISC = 0,
+    PAGE_GENERAL = 0,
     PAGE_VIEW,
     PAGE_PANELTOOLBAR,
     PAGE_MOUSE,
@@ -69,7 +58,7 @@ KgPanel::KgPanel(bool first, QWidget* parent) :
     setWidget(tabWidget);
     setWidgetResizable(true);
 
-    setupMiscTab();
+    setupGeneralTab();
     setupPanelTab();
     setupButtonsTab();
     setupMouseModeTab();
@@ -78,9 +67,9 @@ KgPanel::KgPanel(bool first, QWidget* parent) :
 }
 
 // ---------------------------------------------------------------------------------------
-//  ---------------------------- Misc TAB ------------------------------------------------
+// ---------------------------- General TAB ----------------------------------------------
 // ---------------------------------------------------------------------------------------
-void KgPanel::setupMiscTab()
+void KgPanel::setupGeneralTab()
 {
     QScrollArea *scrollArea = new QScrollArea(tabWidget);
     QWidget *tab = new QWidget(scrollArea);
@@ -89,31 +78,31 @@ void KgPanel::setupMiscTab()
     scrollArea->setWidgetResizable(true);
     tabWidget->addTab(scrollArea, i18n("General"));
 
-    QVBoxLayout *miscLayout = new QVBoxLayout(tab);
-    miscLayout->setSpacing(6);
-    miscLayout->setContentsMargins(11, 11, 11, 11);
+    QVBoxLayout *layout = new QVBoxLayout(tab);
+    layout->setSpacing(6);
+    layout->setContentsMargins(11, 11, 11, 11);
 
 // ---------------------------------------------------------------------------------------
 // ------------------------------- Navigator bar -------------------------------------
 // ---------------------------------------------------------------------------------------
-        QGroupBox *miscGrp = createFrame(i18n("Navigator bar"), tab);
-        QGridLayout *miscGrid = createGridLayout(miscGrp);
+        QGroupBox *groupBox = createFrame(i18n("Navigator bar"), tab);
+        QGridLayout *gridLayout = createGridLayout(groupBox);
 
         KONFIGURATOR_CHECKBOX_PARAM navigatorbar_settings[] = {
             // cfg_class, cfg_name, default, text, restart, tooltip
             {"Look&Feel", "Navigator Edit Mode", false, i18n("Edit Mode by default"),       true, i18n("Show editable path in Navigator bar by default") },
             {"Look&Feel", "Navigator Full Path", false, i18n("Show full path by default"),  true, i18n("Always show full path in Navigator bar by default.") },
         };
-        cbs = createCheckBoxGroup(2, 0, navigatorbar_settings, 2 /*count*/, miscGrp, PAGE_MISC);
-        miscGrid->addWidget(cbs, 0, 0);
+        cbs = createCheckBoxGroup(2, 0, navigatorbar_settings, 2 /*count*/, groupBox, PAGE_GENERAL);
+        gridLayout->addWidget(cbs, 0, 0);
 
-        miscLayout->addWidget(miscGrp);
+        layout->addWidget(groupBox);
 
 // ---------------------------------------------------------------------------------------
 // ------------------------------- Operation ---------------------------------------------
 // ---------------------------------------------------------------------------------------
-    miscGrp = createFrame(i18n("Operation"), tab);
-    miscGrid = createGridLayout(miscGrp);
+    groupBox = createFrame(i18n("Operation"), tab);
+    gridLayout = createGridLayout(groupBox);
 
     KONFIGURATOR_CHECKBOX_PARAM operation_settings[] = { // cfg_class, cfg_name, default, text, restart, tooltip
         {"Look&Feel", "Mark Dirs",            _MarkDirs,          i18n("Autoselect folders"),   false,  i18n("When matching the select criteria, not only files will be selected, but also folders.") },
@@ -121,28 +110,28 @@ void KgPanel::setupMiscTab()
         {"Look&Feel", "UnselectBeforeOperation", _UnselectBeforeOperation, i18n("Unselect files before copy/move"), false, i18n("Unselect files, which are to be copied/moved, before the operation starts.") },
         {"Look&Feel", "FilterDialogRemembersSettings", _FilterDialogRemembersSettings, i18n("Filter dialog remembers settings"), false, i18n("The filter dialog is opened with the last filter settings that where applied to the panel.") },
     };
-    cbs = createCheckBoxGroup(2, 0, operation_settings, 4 /*count*/, miscGrp, PAGE_MISC);
-    miscGrid->addWidget(cbs, 0, 0);
+    cbs = createCheckBoxGroup(2, 0, operation_settings, 4 /*count*/, groupBox, PAGE_GENERAL);
+    gridLayout->addWidget(cbs, 0, 0);
 
-    miscLayout->addWidget(miscGrp);
+    layout->addWidget(groupBox);
 
 // ---------------------------------------------------------------------------------------
 // ------------------------------ Tabs ---------------------------------------------------
 // ---------------------------------------------------------------------------------------
-    miscGrp = createFrame(i18n("Tabs"), tab);
-    miscGrid = createGridLayout(miscGrp);
+    groupBox = createFrame(i18n("Tabs"), tab);
+    gridLayout = createGridLayout(groupBox);
 
     KONFIGURATOR_CHECKBOX_PARAM tabbar_settings[] = { //   cfg_class  cfg_name                default             text                              restart tooltip
         {"Look&Feel", "Fullpath Tab Names",   _FullPathTabNames,  i18n("Use full path tab names"), true ,  i18n("Display the full path in the folder tabs. By default only the last part of the path is displayed.") },
-        {"Look&Feel", "Show Tab Buttons",   true,  i18n("Show new/close tab buttons"), true ,  i18n("Show the new/close tab buttons") },
+        {"Look&Feel", "Show Tab Buttons",   true,  i18n("Show new/close tab buttons"), true ,  i18n("Show the new/close tab buttons.") },
     };
-    KonfiguratorCheckBoxGroup *cbs = createCheckBoxGroup(2, 0, tabbar_settings, 2 /*count*/, miscGrp, PAGE_MISC);
-    miscGrid->addWidget(cbs, 0, 0);
+    KonfiguratorCheckBoxGroup *cbs = createCheckBoxGroup(2, 0, tabbar_settings, 2 /*count*/, groupBox, PAGE_GENERAL);
+    gridLayout->addWidget(cbs, 0, 0, 1, 2);
 
 // -----------------  Tab Bar position ----------------------------------
     QHBoxLayout *hbox = new QHBoxLayout();
 
-    hbox->addWidget(new QLabel(i18n("Tab Bar position:"), miscGrp));
+    hbox->addWidget(new QLabel(i18n("Tab Bar position:"), groupBox));
 
     KONFIGURATOR_NAME_VALUE_PAIR positions[] = {
         { i18n("Top"),      "top" },
@@ -150,65 +139,86 @@ void KgPanel::setupMiscTab()
     };
 
     KonfiguratorComboBox *cmb = createComboBox("Look&Feel", "Tab Bar Position",
-                                "bottom", positions, 2, miscGrp, true, false, PAGE_MISC);
+                                "bottom", positions, 2, groupBox, true, false, PAGE_GENERAL);
 
     hbox->addWidget(cmb);
-    hbox->addWidget(createSpacer(miscGrp));
+    gridLayout->addLayout(hbox, 1, 0, Qt::AlignLeft);
 
-    miscGrid->addLayout(hbox, 1, 0);
+// -----------------  Show Tab bar ----------------------------------
+    KonfiguratorCheckBox *checkBox = createCheckBox("Look&Feel", "Show Tab Bar On Single Tab", true,
+                                                    i18n("Show Tab Bar on single tab"), groupBox,
+                                                    true, i18n("Show the tab bar with only one tab."));
+    gridLayout->addWidget(checkBox, 1, 1, Qt::AlignLeft);
 
-    miscLayout->addWidget(miscGrp);
+    layout->addWidget(groupBox);
 
 // ---------------------------------------------------------------------------------------
 // -----------------------------  Search bar  --------------------------------------------
 // ---------------------------------------------------------------------------------------
-    miscGrp = createFrame(i18n("Search bar"), tab);
-    miscGrid = createGridLayout(miscGrp);
+    groupBox = createFrame(i18n("Search bar"), tab);
+    gridLayout = createGridLayout(groupBox);
 
     KONFIGURATOR_CHECKBOX_PARAM quicksearch[] = { //   cfg_class  cfg_name                default             text                              restart tooltip
         {"Look&Feel", "New Style Quicksearch",  _NewStyleQuicksearch, i18n("Start by typing"), false,  i18n("Open search bar and start searching by typing in panel.") },
         {"Look&Feel", "Case Sensitive Quicksearch",  _CaseSensitiveQuicksearch, i18n("Case sensitive"), false,  i18n("Search must match case.") },
         {"Look&Feel", "Up/Down Cancels Quicksearch",  false, i18n("Up/Down cancels search"), false,  i18n("Pressing the Up/Down buttons closes the search bar (only in search mode).") },
+        {"Look&Feel", "Navigation with Right Arrow Quicksearch", _NavigationWithRightArrowQuicksearch, i18n("Directory navigation with Right Arrow"), false, i18n("Pressing the Right button enters directory if no search text editing intention is captured.") },
     };
 
-    quicksearchCheckboxes = createCheckBoxGroup(2, 0, quicksearch, 3 /*count*/, miscGrp, PAGE_MISC);
-    miscGrid->addWidget(quicksearchCheckboxes, 0, 0, 1, -1);
+    quicksearchCheckboxes = createCheckBoxGroup(2, 0, quicksearch, 4 /*count*/, groupBox, PAGE_GENERAL);
+    gridLayout->addWidget(quicksearchCheckboxes, 0, 0, 1, -1);
     connect(quicksearchCheckboxes->find("New Style Quicksearch"), SIGNAL(stateChanged(int)), this, SLOT(slotDisable()));
     slotDisable();
 
     // -------------- Search bar position -----------------------
 
     hbox = new QHBoxLayout();
-    hbox->addWidget(new QLabel(i18n("Position:"), miscGrp));
+    hbox->addWidget(new QLabel(i18n("Position:"), groupBox));
     cmb = createComboBox("Look&Feel", "Quicksearch Position",
-                            "bottom", positions, 2, miscGrp, true, false, PAGE_MISC);
+                            "bottom", positions, 2, groupBox, true, false, PAGE_GENERAL);
     hbox->addWidget(cmb);
-    hbox->addWidget(createSpacer(miscGrp));
-    miscGrid->addLayout(hbox, 1, 0);
-    miscLayout->addWidget(miscGrp);
+    hbox->addWidget(createSpacer(groupBox));
+    gridLayout->addLayout(hbox, 1, 0);
+    layout->addWidget(groupBox);
 
     // -------------- Default search mode -----------------------
 
     hbox = new QHBoxLayout();
-    hbox->addWidget(new QLabel(i18n("Default mode:"), miscGrp));
+    hbox->addWidget(new QLabel(i18n("Default mode:"), groupBox));
     KONFIGURATOR_NAME_VALUE_PAIR modes[] = {
         { i18n("Search"),   QString::number(KrSearchBar::MODE_SEARCH) },
         { i18n("Select"),   QString::number(KrSearchBar::MODE_SELECT) },
         { i18n("Filter"),   QString::number(KrSearchBar::MODE_FILTER) }
     };
     cmb = createComboBox("Look&Feel", "Default Search Mode",
-                         QString::number(KrSearchBar::MODE_SEARCH), modes, 3, miscGrp, true, false, PAGE_MISC);
+                         QString::number(KrSearchBar::MODE_SEARCH), modes, 3, groupBox, true, false, PAGE_GENERAL);
     cmb->setToolTip(i18n("Set the default mode on first usage"));
     hbox->addWidget(cmb);
-    hbox->addWidget(createSpacer(miscGrp));
-    miscGrid->addLayout(hbox, 1, 1);
-    miscLayout->addWidget(miscGrp);
+    hbox->addWidget(createSpacer(groupBox));
+    gridLayout->addLayout(hbox, 1, 1);
+    layout->addWidget(groupBox);
+
+// --------------------------------------------------------------------------------------------
+// ------------------------------- Bookmark search settings ----------------------------------
+// --------------------------------------------------------------------------------------------
+    groupBox = createFrame(i18n("Bookmark Search"), tab);
+    gridLayout = createGridLayout(groupBox);
+
+    KONFIGURATOR_CHECKBOX_PARAM bookmarkSearchSettings[] =
+    {
+        {"Look&Feel", "Always show search bar", true, i18n("Always show search bar"), false, i18n("Make bookmark search bar always visible") },
+        {"Look&Feel", "Search in special items", false, i18n("Search in special items"), false, i18n("Bookmark search is also applied to special items in bookmark menu like Trash, Popular URLs, Jump Back, etc.") },
+    };
+    KonfiguratorCheckBoxGroup *bookmarkSearchSettingsGroup = createCheckBoxGroup(2, 0, bookmarkSearchSettings,
+                                                                                 2 /*count*/, groupBox, PAGE_GENERAL);
+    gridLayout->addWidget(bookmarkSearchSettingsGroup, 1, 0, 1, 2);
+    layout->addWidget(groupBox);
 
 // --------------------------------------------------------------------------------------------
 // ------------------------------- Status/Totalsbar settings ----------------------------------
 // --------------------------------------------------------------------------------------------
-    miscGrp = createFrame(i18n("Status/Totalsbar"), tab);
-    miscGrid = createGridLayout(miscGrp);
+    groupBox = createFrame(i18n("Status/Totalsbar"), tab);
+    gridLayout = createGridLayout(groupBox);
 
     KONFIGURATOR_CHECKBOX_PARAM barSettings[] =
     {
@@ -216,10 +226,10 @@ void KgPanel::setupMiscTab()
         {"Look&Feel", "ShowSpaceInformation", true, i18n("Show space information"), true,  i18n("Show free/total space on the device") },
     };
     KonfiguratorCheckBoxGroup *barSett = createCheckBoxGroup(2, 0, barSettings,
-                                          2 /*count*/, miscGrp, PAGE_MISC);
-    miscGrid->addWidget(barSett, 1, 0, 1, 2);
+                                          2 /*count*/, groupBox, PAGE_GENERAL);
+    gridLayout->addWidget(barSett, 1, 0, 1, 2);
 
-    miscLayout->addWidget(miscGrp);
+    layout->addWidget(groupBox);
 }
 
 // --------------------------------------------------------------------------------------------
@@ -355,17 +365,31 @@ void KgPanel::setupPanelTab()
     // -------------------- Panel Font ----------------------------------
     QHBoxLayout *hbox = new QHBoxLayout();
 
-    hbox->addWidget(new QLabel(i18n("View font:"), panelGrp));
+    QHBoxLayout *fontLayout = new QHBoxLayout();
+    fontLayout->addWidget(new QLabel(i18n("View font:"), panelGrp));
+    KonfiguratorFontChooser *chsr =
+        createFontChooser("Look&Feel", "Filelist Font", _FilelistFont, panelGrp, true, PAGE_VIEW);
+    fontLayout->addWidget(chsr);
+    fontLayout->addStretch(1);
+    hbox->addLayout(fontLayout, 1);
 
-    KonfiguratorFontChooser * chsr = createFontChooser("Look&Feel", "Filelist Font", _FilelistFont, panelGrp, true, PAGE_VIEW);
-    hbox->addWidget(chsr);
-
-    hbox->addWidget(createSpacer(panelGrp));
+    // -------------------- Panel Tooltip ----------------------------------
+    QHBoxLayout *tooltipLayout = new QHBoxLayout();
+    QLabel *tooltipLabel = new QLabel(i18n("Tooltip delay (msec):"));
+    tooltipLabel->setWhatsThis(i18n("The duration after a tooltip is shown for a file item, in "
+                                    "milliseconds. Set a negative value to disable tooltips."));
+    tooltipLayout->addWidget(tooltipLabel);
+    KonfiguratorSpinBox *tooltipSpinBox = createSpinBox("Look&Feel", "Panel Tooltip Delay", 1000,
+                                                        -100, 5000, panelGrp, false, PAGE_VIEW);
+    tooltipSpinBox->setSingleStep(100);
+    tooltipLayout->addWidget(tooltipSpinBox);
+    tooltipLayout->addStretch(1);
+    hbox->addLayout(tooltipLayout, 1);
 
     panelGrid->addLayout(hbox, 1, 0);
 
 
-    // -------------------- Misc options ----------------------------------
+    // -------------------- General options ----------------------------------
     KONFIGURATOR_CHECKBOX_PARAM panelSettings[] =
         //   cfg_class  cfg_name                default text                                  restart tooltip
     {
@@ -373,9 +397,10 @@ void KgPanel::setupPanelTab()
         {"Look&Feel", "Show Hidden",                    _ShowHidden,             i18n("Show hidden files"),      false,  i18n("Display files beginning with a dot.") },
         {"Look&Feel", "Numeric permissions",            _NumericPermissions,     i18n("Numeric Permissions"), true,  i18n("Show octal numbers (0755) instead of the standard permissions (rwxr-xr-x) in the permission column.") },
         {"Look&Feel", "Load User Defined Folder Icons", _UserDefinedFolderIcons, i18n("Load the user defined folder icons"), true ,  i18n("Load the user defined folder icons (can cause decrease in performance).") },
+        {"Look&Feel", "Always Show Current Item",       _AlwaysShowCurrentItem,  i18n("Always show current item"), false,  i18n("Show current item border decoration in inactive panel.") },
     };
 
-    KonfiguratorCheckBoxGroup *panelSett = createCheckBoxGroup(2, 0, panelSettings, 4 /*count*/, panelGrp, PAGE_VIEW);
+    KonfiguratorCheckBoxGroup *panelSett = createCheckBoxGroup(2, 0, panelSettings, 5 /*count*/, panelGrp, PAGE_VIEW);
 
     panelGrid->addWidget(panelSett, 3, 0, 1, 2);
 
@@ -600,6 +625,9 @@ void KgPanel::setupMouseModeTab()
         {"Custom Selection Mode",  "Space Moves Down",  _SpaceMovesDown,
          i18n("Spacebar moves down"), true,
          i18n("If checked, pressing the spacebar will select the current item and move down.\nOtherwise, current item is selected, but remains the current item.") },
+        {"Custom Selection Mode",  "Space Calc Space",  _SpaceCalcSpace,
+         i18n("Spacebar calculates disk space"), true,
+         i18n("If checked, pressing the spacebar while the current item is a folder, will (except from selecting the folder)\ncalculate space occupied of the folder (recursively).") },
         {"Custom Selection Mode",  "Insert Moves Down",  _InsertMovesDown,
          i18n("Insert moves down"), true,
          i18n("If checked, pressing Insert will select the current item, and move down to the next item.\nOtherwise, current item is not changed.") },
@@ -609,7 +637,7 @@ void KgPanel::setupMouseModeTab()
     };
 
 
-    mouseCheckboxes = createCheckBoxGroup(1, 0, mouseCheckboxesParam, 10 /*count*/, mouseDetailGroup, PAGE_MOUSE);
+    mouseCheckboxes = createCheckBoxGroup(1, 0, mouseCheckboxesParam, 11 /*count*/, mouseDetailGroup, PAGE_MOUSE);
     mouseDetailGrid->addWidget(mouseCheckboxes, 1, 0);
 
     for (int i = 0; i < mouseCheckboxes->count(); i++)
@@ -709,6 +737,7 @@ void KgPanel::slotSelectionModeChanged()
     mouseCheckboxes->find("Right Preserves")->setChecked(selectionMode->rightButtonPreservesSelection());
     mouseCheckboxes->find("ShiftCtrl Right Selects")->setChecked(selectionMode->shiftCtrlRightButtonSelects());
     mouseCheckboxes->find("Space Moves Down")->setChecked(selectionMode->spaceMovesDown());
+    mouseCheckboxes->find("Space Calc Space")->setChecked(selectionMode->spaceCalculatesDiskSpace());
     mouseCheckboxes->find("Insert Moves Down")->setChecked(selectionMode->insertMovesDown());
     mouseCheckboxes->find("Immediate Context Menu")->setChecked(selectionMode->showContextMenu() == -1);
 }
