@@ -1,36 +1,27 @@
-/***************************************************************************
-                         locate.cpp  -  description
-                             -------------------
-    copyright            : (C) 2004 by Csaba Karai
-    e-mail               : krusader@users.sourceforge.net
-    web site             : http://krusader.sourceforge.net
- ---------------------------------------------------------------------------
-  Description
- ***************************************************************************
-
-  A
-
-     db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-     88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-     88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-     88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-     88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-     YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                                     S o u r c e    F i l e
-
- ***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2004 Csaba Karai <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #include "locate.h"
 #include "../kractions.h"
 #include "../krglobal.h"
+#include "../filelisticon.h"
 #include "../krslots.h"
 #include "../krusaderview.h"
 #include "../Panel/krpanel.h"
@@ -42,7 +33,6 @@
 #include "../FileSystem/virtualfilesystem.h"
 #include "../KViewer/krviewer.h"
 #include "../panelmanager.h"
-#include "../kicons.h"
 
 // QtCore
 #include <QRegExp>
@@ -98,7 +88,7 @@ public:
         Q_UNUSED(supportedActs);
 
         QList<QUrl> urls;
-        QList<QTreeWidgetItem *> list = selectedItems() ;
+        QList<QTreeWidgetItem *> list = selectedItems();
 
         QListIterator<QTreeWidgetItem *> it(list);
 
@@ -114,7 +104,7 @@ public:
 
         QDrag *drag = new QDrag(this);
         QMimeData *mimeData = new QMimeData;
-        mimeData->setImageData(FL_LOADICON("file"));
+        mimeData->setImageData(FileListIcon("file").pixmap());
         mimeData->setUrls(urls);
         drag->setMimeData(mimeData);
         drag->start();
@@ -219,12 +209,12 @@ LocateDlg::LocateDlg() : QDialog(0), isFeedToListBox(false)
     mainLayout->addWidget(buttonBox);
 
     locateButton = new QPushButton(i18n("Locate"));
-    locateButton->setIcon(QIcon::fromTheme(QStringLiteral("system-search")));
+    locateButton->setIcon(Icon(QStringLiteral("system-search")));
     locateButton->setDefault(true);
     buttonBox->addButton(locateButton, QDialogButtonBox::ActionRole);
 
     updateDbButton = new QPushButton(i18n("Update DB"));
-    updateDbButton->setIcon(QIcon::fromTheme(QStringLiteral("view-refresh")));
+    updateDbButton->setIcon(Icon(QStringLiteral("view-refresh")));
     buttonBox->addButton(updateDbButton, QDialogButtonBox::ActionRole);
 
     feedStopButton = new QPushButton;
@@ -600,7 +590,7 @@ void LocateDlg::operate(QTreeWidgetItem *item, int task)
             return;
 
         QMimeData *mimeData = new QMimeData;
-        mimeData->setImageData(FL_LOADICON("file"));
+        mimeData->setImageData(FileListIcon("file").pixmap());
         mimeData->setUrls(urls);
 
         QApplication::clipboard()->setMimeData(mimeData, QClipboard::Clipboard);
@@ -639,7 +629,7 @@ bool LocateDlg::find()
 void LocateDlg::feedToListBox()
 {
     VirtualFileSystem virtFilesystem;
-    virtFilesystem.refresh(QUrl::fromLocalFile(QStringLiteral("/")));
+    virtFilesystem.scanDir(QUrl::fromLocalFile(QStringLiteral("/")));
 
     KConfigGroup group(krConfig, "Locate");
     int listBoxNum = group.readEntry("Feed To Listbox Counter", 1);
@@ -666,7 +656,7 @@ void LocateDlg::feedToListBox()
         it++;
     }
     QUrl url = QUrl(QStringLiteral("virt:/") + queryName);
-    virtFilesystem.refresh(url);
+    virtFilesystem.refresh(url); // create directory if it does not exist
     virtFilesystem.addFiles(urlList);
     //ACTIVE_FUNC->openUrl(url);
     ACTIVE_MNG->slotNewTab(url);
@@ -686,16 +676,16 @@ void LocateDlg::updateButtons(bool locateIsRunning)
     if (locateIsRunning) {
         feedStopButton->setEnabled(true);
         feedStopButton->setText(i18n("Stop"));
-        feedStopButton->setIcon(QIcon::fromTheme(QStringLiteral("process-stop")));
+        feedStopButton->setIcon(Icon(QStringLiteral("process-stop")));
     } else {
         if (resultList->topLevelItemCount() == 0) {
             feedStopButton->setEnabled(false);
             feedStopButton->setText(i18n("Stop"));
-            feedStopButton->setIcon(QIcon::fromTheme(QStringLiteral("process-stop")));
+            feedStopButton->setIcon(Icon(QStringLiteral("process-stop")));
         } else {
             feedStopButton->setEnabled(true);
             feedStopButton->setText(i18n("Feed to listbox"));
-            feedStopButton->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
+            feedStopButton->setIcon(Icon(QStringLiteral("list-add")));
         }
     }
 }
