@@ -1,29 +1,33 @@
 /*****************************************************************************
  * Copyright (C) 2010 Jan Lepper <dehtris@yahoo.de>                          *
+ * Copyright (C) 2010-2018 Krusader Krew [https://krusader.org]              *
  *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
  * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
+ * the Free Software Foundation, either version 2 of the License, or         *
  * (at your option) any later version.                                       *
  *                                                                           *
- * This package is distributed in the hope that it will be useful,           *
+ * Krusader is distributed in the hope that it will be useful,               *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
  * GNU General Public License for more details.                              *
  *                                                                           *
  * You should have received a copy of the GNU General Public License         *
- * along with this package; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
  *****************************************************************************/
 
 #include "krsearchbar.h"
 
+#include "PanelView/krview.h"
+#include "PanelView/krviewitem.h"
+#include "../FileSystem/dirlisterinterface.h"
 #include "../defaults.h"
 #include "../krglobal.h"
-#include "../FileSystem/dirlisterinterface.h"
-#include "krview.h"
-#include "krviewitem.h"
+#include "../icon.h"
 
+#include <QDebug>
 #include <QGuiApplication>
 #include <QHBoxLayout>
 #include <QKeyEvent>
@@ -32,17 +36,16 @@
 #include <QToolTip>
 
 #include <KConfigCore/KSharedConfig>
-#include <KIconThemes/KIconLoader>
 #include <KI18n/KLocalizedString>
 
 
 KrSearchBar::KrSearchBar(KrView *view, QWidget *parent)
-    : QWidget(parent), _view(0)
+    : QWidget(parent), _view(0), _rightArrowEntersDirFlag(true)
 {
     // close button
     QToolButton *closeButton = new QToolButton(this);
     closeButton->setAutoRaise(true);
-    closeButton->setIcon(QIcon::fromTheme(QStringLiteral("dialog-close")));
+    closeButton->setIcon(Icon(QStringLiteral("dialog-close")));
     closeButton->setToolTip(i18n("Close the search bar"));
     connect(closeButton, SIGNAL(clicked()), SLOT(hideBar()));
 
@@ -71,13 +74,13 @@ KrSearchBar::KrSearchBar(KrView *view, QWidget *parent)
     connect(_textBox, SIGNAL(currentTextChanged(QString)), SLOT(onSearchChange()));
 
     QToolButton *saveSearchBtn = new QToolButton(this);
-    saveSearchBtn->setIcon(krLoader->loadIcon("document-save", KIconLoader::Toolbar, 16));
+    saveSearchBtn->setIcon(Icon("document-save"));
     saveSearchBtn->setFixedSize(20, 20);
     saveSearchBtn->setToolTip(i18n("Save the current search string"));
     connect(saveSearchBtn, SIGNAL(clicked()), this, SLOT(saveSearchString()));
 
     _openSelectDialogBtn = new QToolButton(this);
-    _openSelectDialogBtn->setIcon(krLoader->loadIcon("configure", KIconLoader::Toolbar, 16));
+    _openSelectDialogBtn->setIcon(Icon("configure"));
     _openSelectDialogBtn->setFixedSize(20, 20);
     _openSelectDialogBtn->setToolTip(i18n("Open selection dialog"));
 
@@ -116,6 +119,7 @@ void KrSearchBar::showBar(SearchMode mode)
     }
     show();
     _textBox->setFocus();
+    _rightArrowEntersDirFlag = true;
 }
 
 void KrSearchBar::hideBar()
@@ -168,7 +172,7 @@ void KrSearchBar::onSearchChange()
             break;
         }
         default:
-            krOut << "unexpected search mode: " << _currentMode;
+            qWarning() << "unexpected search mode: " << _currentMode;
     }
 
     _textBox->setFocus();
@@ -219,6 +223,8 @@ bool KrSearchBar::eventFilter(QObject *watched, QEvent *event)
         return false;
     }
 
+    qDebug() << "key press event=" << event;
+
     QKeyEvent *ke = static_cast<QKeyEvent *>(event);
     if (watched == _view->widget()) {
         KConfigGroup grpSv(krConfig, "Look&Feel");
@@ -229,6 +235,7 @@ bool KrSearchBar::eventFilter(QObject *watched, QEvent *event)
         }
 
         if (!isHidden()) {
+            // view widget has focus but search bar is open and may wants to steal key events
             const bool handled = handleKeyPressEvent(ke);
             if (handled) {
                 return true;
@@ -247,7 +254,8 @@ bool KrSearchBar::eventFilter(QObject *watched, QEvent *event)
         }
 
         if (ke->text().isEmpty() || (ke->modifiers() != Qt::NoModifier &&
-                                     ke->modifiers() != Qt::ShiftModifier)) {
+                                     ke->modifiers() != Qt::ShiftModifier &&
+                                     ke->modifiers() != Qt::KeypadModifier)) {
             return false;
         }
 
@@ -269,13 +277,18 @@ bool KrSearchBar::eventFilter(QObject *watched, QEvent *event)
         }
         return true;
     } else if (watched == _textBox) {
+        const bool handled = handleKeyPressEvent(ke);
+        if (handled) {
+             _view->widget()->setFocus();
+            return true;
+        }
         // allow the view to handle (most) key events from the text box
         if (ke->modifiers() == Qt::NoModifier &&
             ke->key() != Qt::Key_Space &&
             ke->key() != Qt::Key_Backspace &&
             ke->key() != Qt::Key_Left &&
             ke->key() != Qt::Key_Right) {
-            bool handled = _view->handleKeyEvent(ke);
+            const bool handled = _view->handleKeyEvent(ke);
             if (handled) {
                 _view->widget()->setFocus();
                 return true;
@@ -302,6 +315,9 @@ bool KrSearchBar::handleKeyPressEvent(QKeyEvent *ke)
         return handleUpDownKeyPress(true);
     case Qt::Key_Down:
         return handleUpDownKeyPress(false);
+    case Qt::Key_Left:
+    case Qt::Key_Right:
+        return handleLeftRightKeyPress(ke);
     case Qt::Key_Insert: {
         // select current item and jump to next search result
         KrViewItem * item = _view->getCurrentKrViewItem();
@@ -351,6 +367,27 @@ bool KrSearchBar::handleUpDownKeyPress(bool up)
     return true;
 }
 
+bool KrSearchBar::handleLeftRightKeyPress(QKeyEvent *ke)
+{
+    const bool useQuickDirectoryNavigation = KConfigGroup(krConfig, "Look&Feel")
+        .readEntry("Navigation with Right Arrow Quicksearch", true);
+    if (!useQuickDirectoryNavigation)
+        return false;
+
+    const bool isRight = ke->key() == Qt::Key_Right;
+
+    if (isRight && _rightArrowEntersDirFlag) {
+        // in case the Right Arrow has been pressed when cursor is in the end of the line
+        if (_textBox->cursorPosition() == _textBox->currentText().length())
+            // we let the view enter the directory if it's selected
+            return _view->handleKeyEvent(ke);
+    } else {
+        _rightArrowEntersDirFlag = false;
+    }
+
+    return false;
+}
+
 void KrSearchBar::indicateMatch(bool anyMatch)
 {
     KConfigGroup gc(krConfig, "Colors");
