@@ -1,32 +1,23 @@
-/***************************************************************************
-                         listpanel.cpp
-                      -------------------
-copyright            : (C) 2000 by Shie Erlich & Rafi Yanai
-e-mail               : krusader@users.sourceforge.net
-web site             : http://krusader.sourceforge.net
----------------------------------------------------------------------------
-Description
-***************************************************************************
-
-A
-
-db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                              S o u r c e    F i l e
-
-***************************************************************************
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-*                                                                         *
-***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2000 Shie Erlich <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2000 Rafi Yanai <krusader@users.sourceforge.net>            *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #include "listpanel.h"
 
@@ -56,47 +47,51 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 
 #include <KCoreAddons/KUrlMimeData>
 #include <KI18n/KLocalizedString>
-#include <KIconThemes/KIconLoader>
 #include <KIO/DropJob>
 #include <KWidgetsAddons/KCursor>
 #include <KWidgetsAddons/KMessageBox>
 #include <KIOFileWidgets/KFilePlacesModel>
 #include <KIOWidgets/KUrlComboBox>
 
-#include "../defaults.h"
-#include "../krusader.h"
-#include "../krslots.h"
-#include "../kicons.h"
-#include "../krusaderview.h"
-#include "../krservices.h"
-#include "../FileSystem/filesystem.h"
-#include "../FileSystem/krpermhandler.h"
-#include "../Archive/krarchandler.h"
-#include "../MountMan/kmountman.h"
-#include "../BookMan/krbookmarkbutton.h"
-#include "../Dialogs/krdialogs.h"
-#include "../Dialogs/krspwidgets.h"
-#include "../Dialogs/percentalsplitter.h"
-#include "../Dialogs/popularurls.h"
-#include "../GUI/kcmdline.h"
-#include "../GUI/dirhistorybutton.h"
-#include "../GUI/mediabutton.h"
-#include "../GUI/syncbrowsebutton.h"
-#include "../UserAction/useractionpopupmenu.h"
-
-#include "listpanelactions.h"
-#include "viewactions.h"
-#include "krpreviewpopup.h"
-#include "panelpopup.h"
-#include "panelfunc.h"
-#include "krpopupmenu.h"
-#include "krviewfactory.h"
+#include "dirhistoryqueue.h"
 #include "krcolorcache.h"
 #include "krerrordisplay.h"
 #include "krlayoutfactory.h"
+#include "krpreviewpopup.h"
 #include "krsearchbar.h"
-#include "dirhistoryqueue.h"
+#include "listpanelactions.h"
+#include "panelcontextmenu.h"
+#include "panelfunc.h"
+#include "sidebar.h"
+#include "viewactions.h"
 
+#include "PanelView/krview.h"
+#include "PanelView/krviewfactory.h"
+#include "PanelView/krviewitem.h"
+
+#include "../defaults.h"
+#include "../icon.h"
+#include "../krservices.h"
+#include "../krslots.h"
+#include "../krusader.h"
+#include "../krusaderview.h"
+
+#include "../Archive/krarchandler.h"
+#include "../BookMan/krbookmarkbutton.h"
+#include "../FileSystem/fileitem.h"
+#include "../FileSystem/filesystem.h"
+#include "../FileSystem/krpermhandler.h"
+#include "../FileSystem/sizecalculator.h"
+#include "../Dialogs/krdialogs.h"
+#include "../Dialogs/krspwidgets.h"
+#include "../Dialogs/krsqueezedtextlabel.h"
+#include "../Dialogs/percentalsplitter.h"
+#include "../Dialogs/popularurls.h"
+#include "../GUI/dirhistorybutton.h"
+#include "../GUI/kcmdline.h"
+#include "../GUI/mediabutton.h"
+#include "../MountMan/kmountman.h"
+#include "../UserAction/useractionpopupmenu.h"
 
 class ActionButton : public QToolButton
 {
@@ -128,7 +123,7 @@ ListPanel::ListPanel(QWidget *parent, AbstractPanelManager *manager, KConfigGrou
         QWidget(parent), KrPanel(manager, this, new ListPanelFunc(this)),
         panelType(-1), colorMask(255), compareMode(false),
         previewJob(0), inlineRefreshJob(0), searchBar(0), cdRootButton(0), cdUpButton(0),
-        popupBtn(0), popup(0), fileSystemError(0), _navigatorUrl(), _locked(false)
+        sidebarButton(0), sidebar(0), fileSystemError(0), _navigatorUrl(), _tabState(TabState::DEFAULT)
 {
     if(cfg.isValid())
         panelType = cfg.readEntry("Type", -1);
@@ -236,36 +231,46 @@ ListPanel::ListPanel(QWidget *parent, AbstractPanelManager *manager, KConfigGrou
     freeSpace->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
     ADD_WIDGET(freeSpace);
 
+    // progress indicator and cancel button for the quick calc size
+    quickSizeCalcProgress = new QProgressBar(this);
+    quickSizeCalcProgress->hide();
+    ADD_WIDGET(quickSizeCalcProgress);
+    cancelQuickSizeCalcButton = new QToolButton(this);
+    cancelQuickSizeCalcButton->hide();
+    cancelQuickSizeCalcButton->setIcon(Icon("dialog-cancel"));
+    cancelQuickSizeCalcButton->setToolTip(i18n("Cancel directory space calculation"));
+    ADD_WIDGET(cancelQuickSizeCalcButton);
+
     // progress indicator for the preview job
     previewProgress = new QProgressBar(this);
     previewProgress->hide();
     ADD_WIDGET(previewProgress);
 
-    // a cancel button for the inplace refresh mechanism
-    inlineRefreshCancelButton = new QToolButton(this);
-    inlineRefreshCancelButton->hide();
-    inlineRefreshCancelButton->setIcon(krLoader->loadIcon("dialog-cancel", KIconLoader::Toolbar, 16));
-    connect(inlineRefreshCancelButton, SIGNAL(clicked()), this, SLOT(inlineRefreshCancel()));
-    ADD_WIDGET(inlineRefreshCancelButton);
+    // a cancel button for the filesystem refresh and preview job
+    cancelProgressButton = new QToolButton(this);
+    cancelProgressButton->hide();
+    cancelProgressButton->setIcon(Icon("dialog-cancel"));
+    connect(cancelProgressButton, SIGNAL(clicked()), this, SLOT(cancelProgress()));
+    ADD_WIDGET(cancelProgressButton);
 
-    // button for changing the panel popup position in the panel
-    popupPositionBtn = new QToolButton(this);
-    popupPositionBtn->hide();
-    popupPositionBtn->setAutoRaise(true);
-    popupPositionBtn->setIcon(krLoader->loadIcon("exchange-positions", KIconLoader::Toolbar, 16));
-    popupPositionBtn->setToolTip(i18n("Move popup panel clockwise"));
-    connect(popupPositionBtn, &QToolButton::clicked, [this]() {
+    // button for changing the panel sidebar position in the panel
+    sidebarPositionButton = new QToolButton(this);
+    sidebarPositionButton->hide();
+    sidebarPositionButton->setAutoRaise(true);
+    sidebarPositionButton->setIcon(Icon("exchange-positions"));
+    sidebarPositionButton->setToolTip(i18n("Move Sidebar clockwise"));
+    connect(sidebarPositionButton, &QToolButton::clicked, [this]() {
         // moving position clockwise
-        setPopupPosition((popupPosition() + 1) % 4); });
-    ADD_WIDGET(popupPositionBtn);
+        setSidebarPosition((sidebarPosition() + 1) % 4); });
+    ADD_WIDGET(sidebarPositionButton);
 
-    // a quick button to open the popup panel
-    popupBtn = new QToolButton(this);
-    popupBtn->setAutoRaise(true);
-    popupBtn->setIcon(krLoader->loadIcon("arrow-up", KIconLoader::Toolbar, 16));
-    connect(popupBtn, SIGNAL(clicked()), this, SLOT(togglePanelPopup()));
-    popupBtn->setToolTip(i18n("Open the popup panel"));
-    ADD_WIDGET(popupBtn);
+    // a quick button to open the sidebar
+    sidebarButton = new QToolButton(this);
+    sidebarButton->setAutoRaise(true);
+    sidebarButton->setIcon(Icon("arrow-up"));
+    connect(sidebarButton, &QToolButton::clicked, this, &ListPanel::toggleSidebar);
+    sidebarButton->setToolTip(i18n("Open the Sidebar"));
+    ADD_WIDGET(sidebarButton);
 
 #undef ADD_WIDGET
 
@@ -282,22 +287,34 @@ ListPanel::ListPanel(QWidget *parent, AbstractPanelManager *manager, KConfigGrou
     cdRootButton = new ActionButton(toolbar, this, _actions->actRoot, "/");
     toolbarLayout->addWidget(cdRootButton);
 
-    // ... creates the button for sync-browsing
-    syncBrowseButton = new SyncBrowseButton(toolbar);
+    // create the button for sync-browsing
+    syncBrowseButton = new QToolButton(toolbar);
+    syncBrowseButton->setIcon(Icon("kr_syncbrowse_off"));
+    syncBrowseButton->setCheckable(true);
+
+    const QString syncBrowseText = i18n("This button toggles the sync-browse mode.\n"
+                                        "When active, each folder change is performed in the\n"
+                                        "active and inactive panel - if possible.");
+    syncBrowseButton->setText(syncBrowseText);
+    syncBrowseButton->setToolTip(syncBrowseText);
+    connect(syncBrowseButton, &QToolButton::toggled, [=](bool checked) {
+        syncBrowseButton->setIcon(
+            Icon(checked ? "kr_syncbrowse_on" : "kr_syncbrowse_off"));
+    });
     syncBrowseButton->setAutoRaise(true);
     toolbarLayout->addWidget(syncBrowseButton);
 
     setButtons();
 
-    // create a splitter to hold the view and the popup
-    splt = new PercentalSplitter(clientArea);
-    splt->setChildrenCollapsible(true);
-    splt->setOrientation(Qt::Vertical);
+    // create a splitter to hold the view and the sidebar
+    sidebarSplitter = new PercentalSplitter(clientArea);
+    sidebarSplitter->setChildrenCollapsible(true);
+    sidebarSplitter->setOrientation(Qt::Horizontal);
     // expand vertical if splitter orientation is horizontal
-    QSizePolicy sizePolicy = splt->sizePolicy();
+    QSizePolicy sizePolicy = sidebarSplitter->sizePolicy();
     sizePolicy.setVerticalPolicy(QSizePolicy::Expanding);
-    splt->setSizePolicy(sizePolicy);
-    clientLayout->addWidget(splt);
+    sidebarSplitter->setSizePolicy(sizePolicy);
+    clientLayout->addWidget(sidebarSplitter);
 
     // view
     createView();
@@ -344,9 +361,11 @@ ListPanel::ListPanel(QWidget *parent, AbstractPanelManager *manager, KConfigGrou
         h->setSpacing(0);
         h->addWidget(totals);
         h->addWidget(freeSpace);
+        h->addWidget(quickSizeCalcProgress);
+        h->addWidget(cancelQuickSizeCalcButton);
         h->addWidget(previewProgress);
-        h->addWidget(inlineRefreshCancelButton);
-        h->addWidget(popupBtn);
+        h->addWidget(cancelProgressButton);
+        h->addWidget(sidebarButton);
         v->addLayout(h);
 
         layout = v;
@@ -355,12 +374,12 @@ ListPanel::ListPanel(QWidget *parent, AbstractPanelManager *manager, KConfigGrou
     setLayout(layout);
 
     connect(&KrColorCache::getColorCache(), SIGNAL(colorsRefreshed()), this, SLOT(refreshColors()));
-    connect(krApp, SIGNAL(shutdown()), SLOT(inlineRefreshCancel()));
+    connect(krApp, SIGNAL(shutdown()), SLOT(cancelProgress()));
 }
 
 ListPanel::~ListPanel()
 {
-    inlineRefreshCancel();
+    cancelProgress();
     delete view;
     view = 0;
     delete func;
@@ -396,7 +415,7 @@ bool ListPanel::isNavigatorEditModeSet()
 
 void ListPanel::createView()
 {
-    view = KrViewFactory::createView(panelType, splt, krConfig);
+    view = KrViewFactory::createView(panelType, sidebarSplitter, krConfig);
     view->init();
     view->setMainWindow(krApp);
 
@@ -409,10 +428,11 @@ void ListPanel::createView()
         view->prepareForPassive();
     view->refreshColors();
 
-    splt->insertWidget(popupPosition() < 2 ? 1 : 0, view->widget());
+    sidebarSplitter->insertWidget(sidebarPosition() < 2 ? 1 : 0, view->widget());
 
     view->widget()->installEventFilter(this);
 
+    connect(view->op(), &KrViewOperator::quickCalcSpace, func, &ListPanelFunc::quickCalcSpace);
     connect(view->op(), SIGNAL(goHome()), func, SLOT(home()));
     connect(view->op(), SIGNAL(dirUp()), func, SLOT(dirUp()));
     connect(view->op(), &KrViewOperator::defaultDeleteFiles, func, &ListPanelFunc::defaultDeleteFiles);
@@ -468,17 +488,27 @@ void ListPanel::changeType(int type)
 int ListPanel::getProperties()
 {
     int props = 0;
-    if (syncBrowseButton->state() == SYNCBROWSE_CD)
+    if (syncBrowseButton->isChecked()) {
         props |= PROP_SYNC_BUTTON_ON;
-    if (_locked)
+    }
+    if (isLocked()) {
         props |= PROP_LOCKED;
+    } else if (isPinned()) {
+        props |= PROP_PINNED;
+    }
     return props;
 }
 
 void ListPanel::setProperties(int prop)
 {
     syncBrowseButton->setChecked(prop & PROP_SYNC_BUTTON_ON);
-    _locked = (prop & PROP_LOCKED);
+    if (prop & PROP_LOCKED) {
+        _tabState = TabState::LOCKED;
+    } else if (prop & PROP_PINNED) {
+        _tabState = TabState::PINNED;
+    } else {
+        _tabState = TabState::DEFAULT;
+    }
 }
 
 bool ListPanel::eventFilter(QObject * watched, QEvent * e)
@@ -523,44 +553,44 @@ bool ListPanel::eventFilter(QObject * watched, QEvent * e)
     return false;
 }
 
-void ListPanel::togglePanelPopup()
+void ListPanel::toggleSidebar()
 {
-    if(!popup) {
-        popup = new PanelPopup(splt, isLeft(), krApp);
+    if(!sidebar) {
+        sidebar = new Sidebar(sidebarSplitter);
         // fix vertical grow of splitter (and entire window) if its content
         // demands more space
-        QSizePolicy sizePolicy = popup->sizePolicy();
+        QSizePolicy sizePolicy = sidebar->sizePolicy();
         sizePolicy.setVerticalPolicy(QSizePolicy::Ignored);
-        popup->setSizePolicy(sizePolicy);
-        connect(this, SIGNAL(pathChanged(QUrl)), popup, SLOT(onPanelPathChange(QUrl)));
-        connect(popup, SIGNAL(selection(QUrl)), SLOTS, SLOT(refresh(QUrl)));
-        connect(popup, SIGNAL(hideMe()), this, SLOT(togglePanelPopup()));
+        sidebar->setSizePolicy(sizePolicy);
+        connect(this, &ListPanel::pathChanged, sidebar, &Sidebar::onPanelPathChange);
+        connect(sidebar, &Sidebar::urlActivated, SLOTS, &KRslots::refresh);
+        sidebarSplitter->insertWidget(0, sidebar);
     }
 
-    if (popup->isHidden()) {
-        if (popupSizes.count() > 0) {
-            splt->setSizes(popupSizes);
+    if (sidebar->isHidden()) {
+        if (sidebarSplitterSizes.count() > 0) {
+            sidebarSplitter->setSizes(sidebarSplitterSizes);
         } else { // on the first time, resize to 50%
             QList<int> lst;
             lst << height() / 2 << height() / 2;
-            splt->setSizes(lst);
+            sidebarSplitter->setSizes(lst);
         }
 
-        popup->show();
-        popupBtn->setIcon(krLoader->loadIcon("arrow-down", KIconLoader::Toolbar, 16));
-        popupBtn->setToolTip(i18n("Close the popup panel"));
-        popupPositionBtn->show();
+        sidebar->show();
+        sidebarButton->setIcon(Icon("arrow-down"));
+        sidebarButton->setToolTip(i18n("Close the Sidebar"));
+        sidebarPositionButton->show();
     } else {
-        popupSizes.clear();
-        popupSizes = splt->sizes();
-        popup->hide();
-        popupBtn->setIcon(krLoader->loadIcon("arrow-up", KIconLoader::Toolbar, 16));
-        popupBtn->setToolTip(i18n("Open the popup panel"));
-        popupPositionBtn->hide();
+        sidebarSplitterSizes.clear();
+        sidebarSplitterSizes = sidebarSplitter->sizes();
+        sidebar->hide();
+        sidebarButton->setIcon(Icon("arrow-up"));
+        sidebarButton->setToolTip(i18n("Open the Sidebar"));
+        sidebarPositionButton->hide();
 
         QList<int> lst;
         lst << height() << 0;
-        splt->setSizes(lst);
+        sidebarSplitter->setSizes(lst);
         if (ACTIVE_PANEL)
             ACTIVE_PANEL->gui->slotFocusOnMe();
     }
@@ -625,7 +655,7 @@ void ListPanel::compareDirs(bool otherPanelToo)
         if (item->name() == "..")
             continue;
 
-        for (otherItem = otherPanel()->view->getFirst(); otherItem != 0 && otherItem->name() != item->name() ;
+        for (otherItem = otherPanel()->view->getFirst(); otherItem != 0 && otherItem->name() != item->name();
                 otherItem = otherPanel()->view->getNext(otherItem));
 
         bool isSingle = (otherItem == 0), isDifferent = false, isNewer = false;
@@ -697,7 +727,6 @@ void ListPanel::slotFocusOnMe(bool focus)
 
     urlNavigator->setActive(focus);
     refreshColors();
-    emit refreshPathLabel();
 
     krApp->setUpdatesEnabled(true);
 }
@@ -795,13 +824,13 @@ void ListPanel::handleDrop(QDropEvent *event, bool onView)
         const FileItem *file = item->getFileItem();
         if (file && !file->isDir() && dragFromThisPanel) {
             event->ignore(); // dragging on files in same panel, ignore
-            return ;
+            return;
         } else if (!file || file->isDir()) { // item is ".." dummy or a directory
             destinationDir = item->name();
         }
     } else if (dragFromThisPanel) {
         event->ignore(); // dragged from this panel onto an empty spot in this panel, ignore
-        return ;
+        return;
     }
 
     QUrl destination = QUrl(virtualPath());
@@ -844,12 +873,12 @@ void ListPanel::popRightClickMenu(const QPoint &loc)
 {
     // run it, on the mouse location
     int j = QFontMetrics(font()).height() * 2;
-    KrPopupMenu::run(QPoint(loc.x() + 5, loc.y() + j), this);
+    PanelContextMenu::run(QPoint(loc.x() + 5, loc.y() + j), this);
 }
 
 void ListPanel::popEmptyRightClickMenu(const QPoint &loc)
 {
-    KrPopupMenu::run(loc, this);
+    PanelContextMenu::run(loc, this);
 }
 
 QString ListPanel::getCurrentName()
@@ -861,9 +890,17 @@ QString ListPanel::getCurrentName()
         return QString();
 }
 
+QStringList ListPanel::getSelectedNames()
+{
+    QStringList fileNames;
+    view->getSelectedItems(&fileNames);
+    return fileNames;
+}
+
 void ListPanel::prepareToDelete()
 {
-    view->setNameToMakeCurrent(view->firstUnmarkedBelowCurrent());
+    const bool skipCurrent = (view->numSelected() == 0);
+    view->setNameToMakeCurrent(view->firstUnmarkedBelowCurrent(skipCurrent));
 }
 
 void ListPanel::keyPressEvent(QKeyEvent *e)
@@ -873,13 +910,16 @@ void ListPanel::keyPressEvent(QKeyEvent *e)
     case Qt::Key_Return :
         if (e->modifiers() & Qt::ControlModifier) {
             if (e->modifiers() & Qt::AltModifier) {
-                FileItem *fileitem = func->files()->getFileItem(view->getCurrentKrViewItem()->name());
+                FileItem *fileitem =
+                    func->files()->getFileItem(view->getCurrentKrViewItem()->name());
                 if (fileitem && fileitem->isDir())
                     newTab(fileitem->getUrl(), true);
             } else {
-                SLOTS->insertFileName((e->modifiers()&Qt::ShiftModifier)!=0);
+                SLOTS->insertFileName((e->modifiers() & Qt::ShiftModifier) != 0);
             }
-        } else e->ignore();
+        } else {
+            e->ignore();
+        }
         break;
     case Qt::Key_Right :
     case Qt::Key_Left :
@@ -910,7 +950,7 @@ void ListPanel::keyPressEvent(QKeyEvent *e)
             } else {
                 func->openUrl(otherPanel()->virtualPath());
             }
-            return ;
+            return;
         } else
             e->ignore();
         break;
@@ -920,7 +960,7 @@ void ListPanel::keyPressEvent(QKeyEvent *e)
                 MAIN_VIEW->cmdLineFocus();
             else
                 MAIN_VIEW->focusTerminalEmulator();
-            return ;
+            return;
         } else if (e->modifiers() == (Qt::ControlModifier | Qt::ShiftModifier)) {     // give the keyboard focus to TE
             MAIN_VIEW->focusTerminalEmulator();
         } else
@@ -930,13 +970,13 @@ void ListPanel::keyPressEvent(QKeyEvent *e)
     case Qt::Key_Up :
         if (e->modifiers() == Qt::ControlModifier) {   // give the keyboard focus to the url navigator
             editLocation();
-            return ;
+            return;
         } else
             e->ignore();
         break;
 
     case Qt::Key_Escape:
-        inlineRefreshCancel();
+        cancelProgress();
         break;
 
     default:
@@ -976,11 +1016,11 @@ void ListPanel::slotPreviewJobStarted(KJob *job)
     previewJob = job;
     connect(job, SIGNAL(percent(KJob*,ulong)), SLOT(slotPreviewJobPercent(KJob*,ulong)));
     connect(job, &KJob::result, this, &ListPanel::slotPreviewJobResult);
-    inlineRefreshCancelButton->setMaximumHeight(popupBtn->height());
-    inlineRefreshCancelButton->show();
+    cancelProgressButton->setMaximumHeight(sidebarButton->height());
+    cancelProgressButton->show();
     previewProgress->setValue(0);
     previewProgress->setFormat(i18n("loading previews: %p%"));
-    previewProgress->setMaximumHeight(inlineRefreshCancelButton->height());
+    previewProgress->setMaximumHeight(cancelProgressButton->height());
     previewProgress->show();
 }
 
@@ -994,10 +1034,10 @@ void ListPanel::slotPreviewJobResult(KJob* /*job*/)
     previewJob = 0;
     previewProgress->hide();
     if(!inlineRefreshJob)
-        inlineRefreshCancelButton->hide();
+        cancelProgressButton->hide();
 }
 
-void ListPanel::slotJobStarted(KIO::Job* job)
+void ListPanel::slotRefreshJobStarted(KIO::Job* job)
 {
     // disable the parts of the panel we don't want touched
     status->setEnabled(false);
@@ -1006,9 +1046,9 @@ void ListPanel::slotJobStarted(KIO::Job* job)
     cdHomeButton->setEnabled(false);
     cdUpButton->setEnabled(false);
     cdOtherButton->setEnabled(false);
-    popupBtn->setEnabled(false);
-    if(popup)
-        popup->setEnabled(false);
+    sidebarButton->setEnabled(false);
+    if(sidebar)
+        sidebar->setEnabled(false);
     bookmarksButton->setEnabled(false);
     historyButton->setEnabled(false);
     syncBrowseButton->setEnabled(false);
@@ -1024,10 +1064,10 @@ void ListPanel::slotJobStarted(KIO::Job* job)
     inlineRefreshJob = job;
 
     totals->setText(i18n(">> Reading..."));
-    inlineRefreshCancelButton->show();
+    cancelProgressButton->show();
 }
 
-void ListPanel::inlineRefreshCancel()
+void ListPanel::cancelProgress()
 {
     if (inlineRefreshJob) {
         disconnect(inlineRefreshJob, 0, this, 0);
@@ -1070,15 +1110,15 @@ void ListPanel::inlineRefreshListResult(KJob*)
     cdHomeButton->setEnabled(true);
     cdUpButton->setEnabled(true);
     cdOtherButton->setEnabled(true);
-    popupBtn->setEnabled(true);
-    if(popup)
-        popup->setEnabled(true);
+    sidebarButton->setEnabled(true);
+    if(sidebar)
+        sidebar->setEnabled(true);
     bookmarksButton->setEnabled(true);
     historyButton->setEnabled(true);
     syncBrowseButton->setEnabled(true);
 
     if(!previewJob)
-        inlineRefreshCancelButton->hide();
+        cancelProgressButton->hide();
 }
 
 void ListPanel::jumpBack()
@@ -1159,16 +1199,17 @@ void ListPanel::saveSettings(KConfigGroup cfg, bool saveHistory)
     cfg.writeEntry("Url", url.toString());
     cfg.writeEntry("Type", getType());
     cfg.writeEntry("Properties", getProperties());
+    cfg.writeEntry("PinnedUrl", pinnedUrl().toString());
     if(saveHistory)
         func->history->save(KConfigGroup(&cfg, "History"));
     view->saveSettings(KConfigGroup(&cfg, "View"));
 
-    // splitter/popup state
-    if (popup && !popup->isHidden()) {
-        popup->saveSettings(KConfigGroup(&cfg, "PanelPopup"));
-        cfg.writeEntry("PopupPosition", popupPosition());
-        cfg.writeEntry("SplitterSizes", splt->saveState());
-        cfg.writeEntry("PopupPage", popup->currentPage());
+    // splitter/sidebar state
+    if (sidebar && !sidebar->isHidden()) {
+        sidebar->saveSettings(KConfigGroup(&cfg, "PanelPopup"));
+        cfg.writeEntry("PopupPosition", sidebarPosition());
+        cfg.writeEntry("SplitterSizes", sidebarSplitter->saveState());
+        cfg.writeEntry("PopupPage", sidebar->currentPage());
     } else {
         cfg.deleteEntry("PopupPosition");
         cfg.deleteEntry("SplitterSizes");
@@ -1179,12 +1220,14 @@ void ListPanel::saveSettings(KConfigGroup cfg, bool saveHistory)
 void ListPanel::restoreSettings(KConfigGroup cfg)
 {
     changeType(cfg.readEntry("Type", defaultPanelType()));
-
-    setProperties(cfg.readEntry("Properties", 0));
     view->restoreSettings(KConfigGroup(&cfg, "View"));
 
-    _lastLocalPath = ROOT_DIR;
+    // "locked" property must be set after URL path is restored!
+    // This panel can be reused when loading a profile,
+    // so we reset its properties before calling openUrl().
+    setProperties(0);
 
+    _lastLocalPath = ROOT_DIR;
     if(func->history->restore(KConfigGroup(&cfg, "History"))) {
         func->refresh();
     } else {
@@ -1196,12 +1239,23 @@ void ListPanel::restoreSettings(KConfigGroup cfg)
 
     setJumpBack(func->history->currentUrl());
 
-    if (cfg.hasKey("PopupPosition")) { // popup was visible, restore
-        togglePanelPopup(); // create and show
-        popup->restoreSettings(KConfigGroup(&cfg, "PanelPopup"));
-        setPopupPosition(cfg.readEntry("PopupPosition", 42 /* dummy */));
-        splt->restoreState(cfg.readEntry("SplitterSizes", QByteArray()));
-        popup->setCurrentPage(cfg.readEntry("PopupPage", 0));
+    setProperties(cfg.readEntry("Properties", 0));
+
+    if (isPinned()) {
+        QUrl pinnedUrl(cfg.readEntry("PinnedUrl", "invalid"));
+        if (!pinnedUrl.isValid()) {
+            pinnedUrl = func->history->currentUrl();
+        }
+        func->openUrl(pinnedUrl);
+        setPinnedUrl(pinnedUrl);
+    }
+
+    if (cfg.hasKey("PopupPosition")) { // sidebar was visible, restore
+        toggleSidebar(); // create and show
+        sidebar->restoreSettings(KConfigGroup(&cfg, "PanelPopup"));
+        setSidebarPosition(cfg.readEntry("PopupPosition", 42 /* dummy */));
+        sidebarSplitter->restoreState(cfg.readEntry("SplitterSizes", QByteArray()));
+        sidebar->setCurrentPage(cfg.readEntry("PopupPage", 0));
     }
 }
 
@@ -1211,16 +1265,17 @@ void ListPanel::slotCurrentChanged(KrViewItem *item)
     if (item)
         krApp->statusBarUpdate(item->description());
 
-    // update popup panel; which panel to display on?
-    PanelPopup *p;
-    if(popup && !popup->isHidden())
-        p = popup;
-    else if(otherPanel()->gui->popup && !otherPanel()->gui->popup->isHidden())
-        p = otherPanel()->gui->popup;
-    else
+    // update sidebar; which panel to display on?
+    Sidebar *p;
+    if (sidebar && !sidebar->isHidden()) {
+        p = sidebar;
+    } else if(otherPanel()->gui->sidebar && !otherPanel()->gui->sidebar->isHidden()) {
+        p = otherPanel()->gui->sidebar;
+    } else {
         return;
+    }
 
-    p->update(item ? func->files()->getFileItem(item->name()) : 0);
+    p->update(item ? func->files()->getFileItem(item->name()) : nullptr);
 }
 
 void ListPanel::otherPanelChanged()
@@ -1234,8 +1289,8 @@ void ListPanel::getFocusCandidates(QVector<QWidget*> &widgets)
         widgets << urlNavigator->editor();
     if(view->widget()->isVisible())
         widgets << view->widget();
-    if(popup && popup->isVisible())
-        widgets << popup;
+    if(sidebar && sidebar->isVisible())
+        widgets << sidebar;
 }
 
 void ListPanel::updateButtons()
@@ -1263,6 +1318,11 @@ void ListPanel::newTab(KrViewItem *it)
     }
 }
 
+void ListPanel::newTab(const QUrl &url, bool nextToThis)
+{
+    _manager->newTab(url, nextToThis ? this : 0);
+}
+
 void ListPanel::slotNavigatorUrlChanged(const QUrl &url)
 {
     if (url == _navigatorUrl)
@@ -1288,16 +1348,31 @@ void ListPanel::resetNavigatorMode()
     }
 }
 
-int ListPanel::popupPosition() const
+int ListPanel::sidebarPosition() const
 {
-    int pos = splt->orientation() == Qt::Vertical ? 1 : 0;
-    return pos + (qobject_cast<PanelPopup*>(splt->widget(0)) == NULL ? 2 : 0);
+    int pos = sidebarSplitter->orientation() == Qt::Vertical ? 1 : 0;
+    return pos + (qobject_cast<Sidebar*>(sidebarSplitter->widget(0)) == NULL ? 2 : 0);
 }
 
-void ListPanel::setPopupPosition(int pos)
+void ListPanel::setSidebarPosition(int pos)
 {
-    splt->setOrientation(pos % 2 == 0 ? Qt::Horizontal : Qt::Vertical);
-    if ((pos < 2) != (qobject_cast<PanelPopup*>(splt->widget(0)) != NULL)) {
-        splt->insertWidget(0, splt->widget(1)); // swapping widgets in splitter
+    sidebarSplitter->setOrientation(pos % 2 == 0 ? Qt::Horizontal : Qt::Vertical);
+    if ((pos < 2) != (qobject_cast<Sidebar*>(sidebarSplitter->widget(0)) != NULL)) {
+        sidebarSplitter->insertWidget(0, sidebarSplitter->widget(1)); // swapping widgets in splitter
     }
 }
+
+void ListPanel::connectQuickSizeCalculator(SizeCalculator *sizeCalculator)
+{
+    connect(sizeCalculator, &SizeCalculator::started, this, [=]() {
+        quickSizeCalcProgress->reset();
+        quickSizeCalcProgress->show();
+        cancelQuickSizeCalcButton->show();
+    });
+    connect(cancelQuickSizeCalcButton, &QToolButton::clicked, sizeCalculator, &SizeCalculator::cancel);
+    connect(sizeCalculator, &SizeCalculator::progressChanged, quickSizeCalcProgress, &QProgressBar::setValue);
+    connect(sizeCalculator, &SizeCalculator::finished, this, [=]() {
+        cancelQuickSizeCalcButton->hide();
+        quickSizeCalcProgress->hide();
+    });
+}
