@@ -1,33 +1,23 @@
-/***************************************************************************
-                               listpanel.h
-                            -------------------
-   begin                : Thu May 4 2000
-   copyright            : (C) 2000 by Shie Erlich & Rafi Yanai
-   e-mail               : krusader@users.sourceforge.net
-   web site             : http://krusader.sourceforge.net
----------------------------------------------------------------------------
- Description
-***************************************************************************
-
- A
-
-    db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-    88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-    88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-    88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-    88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-    YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                                    H e a d e r    F i l e
-
-***************************************************************************
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-*                                                                         *
-***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2000 Shie Erlich <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2000 Rafi Yanai <krusader@users.sourceforge.net>            *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 
 #ifndef LISTPANEL_H
@@ -53,37 +43,48 @@
 #include <QWidget>
 #include <QLabel>
 #include <QLayout>
+#include <QSplitter>
 #include <QToolButton>
 #include <QGridLayout>
 
-#include <KIOCore/KFileItem>
 #include <KCompletion/KLineEdit>
+#include <KConfigCore/KConfigGroup>
+#include <KIO/Job>
+#include <KIOCore/KFileItem>
 #include <KIOFileWidgets/KUrlNavigator>
 
 #include "krpanel.h"
-#include "krviewitem.h"
-#include "../Dialogs/krsqueezedtextlabel.h"
 
 #define PROP_SYNC_BUTTON_ON               1
 #define PROP_LOCKED                       2
+#define PROP_PINNED                       4
 
-class KrView;
-class KrSearchBar;
 class DirHistoryButton;
-class MediaButton;
-class PanelPopup;
-class SyncBrowseButton;
 class KrBookmarkButton;
-class ListPanelFunc;
-class QSplitter;
 class KrErrorDisplay;
+class KrSqueezedTextLabel;
+class KrSearchBar;
+class KrView;
+class KrViewItem;
 class ListPanelActions;
+class ListPanelFunc;
+class MediaButton;
+class Sidebar;
+class SizeCalculator;
 
 class ListPanel : public QWidget, public KrPanel
 {
     friend class ListPanelFunc;
     Q_OBJECT
 public:
+
+    enum TabState {
+        DEFAULT,
+        LOCKED,
+        // locked tab with changeable address
+        PINNED
+    };
+
     // constructor create the panel, but DOESN'T fill it with data, use start()
     ListPanel(QWidget *parent, AbstractPanelManager *manager, KConfigGroup cfg = KConfigGroup());
     ~ListPanel();
@@ -99,10 +100,13 @@ public:
     }
     void changeType(int);
     bool isLocked() {
-        return _locked;
+        return _tabState == TabState::LOCKED;
     }
-    void setLocked(bool lck) {
-        _locked = lck;
+    bool isPinned() {
+        return _tabState == TabState::PINNED;
+    }
+    void setTabState(TabState tabState) {
+        _tabState = tabState;
     }
 
     ListPanelActions *actions() {
@@ -110,11 +114,7 @@ public:
     }
     QString lastLocalPath() const;
     QString getCurrentName();
-    QStringList getSelectedNames() {
-        QStringList fileNames;
-        view->getSelectedItems(&fileNames);
-        return fileNames;
-    }
+    QStringList getSelectedNames();
     void setButtons();
     void setJumpBack(QUrl url);
 
@@ -126,6 +126,9 @@ public:
     void saveSettings(KConfigGroup cfg, bool saveHistory);
     void restoreSettings(KConfigGroup cfg);
 
+    void setPinnedUrl(QUrl &pinnedUrl) { _pinnedUrl = pinnedUrl; };
+    QUrl pinnedUrl() const { return _pinnedUrl; };
+
 public slots:
     void popRightClickMenu(const QPoint&);
     void popEmptyRightClickMenu(const QPoint &);
@@ -134,11 +137,11 @@ public slots:
     void slotUpdateTotals();
     // react to file changes in filesystem (path change or refresh)
     void slotStartUpdate(bool directoryChange);
-    void togglePanelPopup();
+    void toggleSidebar();
     void panelVisible(); // called when the panel becomes active
     void panelHidden(); // called when panel becomes inactive
     void refreshColors();
-    void inlineRefreshCancel();
+    void cancelProgress(); // cancel filesystem refresh and/or preview (if running)
     void setNavigatorUrl(const QUrl &url);
 
     void openMedia();
@@ -182,15 +185,13 @@ protected slots:
     void slotPreviewJobPercent(KJob *job, unsigned long percent);
     void slotPreviewJobResult(KJob *job);
     // those handle the in-panel refresh notifications
-    void slotJobStarted(KIO::Job* job);
+    void slotRefreshJobStarted(KIO::Job* job);
     void inlineRefreshInfoMessage(KJob* job, const QString &msg);
     void inlineRefreshListResult(KJob* job);
     void inlineRefreshPercent(KJob*, unsigned long);
     void slotFilesystemError(QString msg);
     void newTab(KrViewItem *item);
-    void newTab(const QUrl &url, bool nextToThis = false) {
-        _manager->newTab(url, nextToThis ? this : 0);
-    }
+    void newTab(const QUrl &url, bool nextToThis = false);
     void slotNavigatorUrlChanged(const QUrl &url);
     void resetNavigatorMode(); // set navigator mode after focus was lost
     // update filesystem meta info, disk-free and mount status
@@ -203,8 +204,6 @@ signals:
     void activate(); // emitted when the user changes panels
     void finishedDragging(); // NOTE: currently not used
     void refreshColors(bool active);
-    // emitted when we have to update the path label width
-    void refreshPathLabel();
 
 protected:
     int panelType;
@@ -219,7 +218,7 @@ protected:
 
     QPixmap currDragPix;
     QWidget *clientArea;
-    QSplitter *splt;
+    QSplitter *sidebarSplitter;
     KUrlNavigator* urlNavigator;
     KrSearchBar* searchBar;
     QToolButton *backButton, *forwardButton;
@@ -227,28 +226,32 @@ protected:
     QToolButton *cdHomeButton;
     QToolButton *cdUpButton;
     QToolButton *cdOtherButton;
-    QToolButton *popupPositionBtn;
-    QToolButton *popupBtn;
-    PanelPopup *popup; // lazy initialized
+    QToolButton *sidebarPositionButton;
+    QToolButton *sidebarButton;
+    Sidebar *sidebar; // lazy initialized
     KrBookmarkButton *bookmarksButton;
     KrSqueezedTextLabel *status, *totals, *freeSpace;
 
+    QProgressBar *quickSizeCalcProgress;
+    QToolButton *cancelQuickSizeCalcButton;
     QProgressBar *previewProgress;
     DirHistoryButton* historyButton;
     MediaButton *mediaButton;
-    SyncBrowseButton *syncBrowseButton;
-    QToolButton *inlineRefreshCancelButton;
+    QToolButton *syncBrowseButton;
+    QToolButton *cancelProgressButton; // for thumbnail previews and filesystem refresh
     KrErrorDisplay *fileSystemError;
 
 private:
     bool handleDropInternal(QDropEvent *event, const QString &dir);
-    int popupPosition() const; // 0: West, 1: North, 2: East, 3: South
-    void setPopupPosition(int);
+    int sidebarPosition() const; // 0: West, 1: North, 2: East, 3: South
+    void setSidebarPosition(int);
+    void connectQuickSizeCalculator(SizeCalculator *sizeCalculator);
 
 private:
     QUrl _navigatorUrl; // distinguish between new user set URL and new custom set URL
-    bool _locked;
-    QList<int> popupSizes;
+    QUrl _pinnedUrl; // only for TabState::PINNED
+    TabState _tabState;
+    QList<int> sidebarSplitterSizes;
 };
 
 #endif
