@@ -1,32 +1,23 @@
-/***************************************************************************
-                            panelfunc.cpp
-                         -------------------
-copyright            : (C) 2000 by Shie Erlich & Rafi Yanai
-e-mail               : krusader@users.sourceforge.net
-web site             : http://krusader.sourceforge.net
----------------------------------------------------------------------------
-Description
-***************************************************************************
-
-A
-
- db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
- 88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
- 88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
- 88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
- 88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
- YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                                 S o u r c e    F i l e
-
-***************************************************************************
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-*                                                                         *
-***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2000 Shie Erlich <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2000 Rafi Yanai <krusader@users.sourceforge.net>            *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #include "panelfunc.h"
 
@@ -64,9 +55,11 @@ A
 
 #include "dirhistoryqueue.h"
 #include "krcalcspacedialog.h"
-#include "listpanel.h"
 #include "krerrordisplay.h"
+#include "listpanel.h"
 #include "listpanelactions.h"
+#include "PanelView/krview.h"
+#include "PanelView/krviewitem.h"
 #include "../krglobal.h"
 #include "../krslots.h"
 #include "../kractions.h"
@@ -86,14 +79,13 @@ A
 #include "../Dialogs/krspwidgets.h"
 #include "../Dialogs/checksumdlg.h"
 #include "../KViewer/krviewer.h"
-#include "../GUI/syncbrowsebutton.h"
 #include "../MountMan/kmountman.h"
 
 QPointer<ListPanelFunc> ListPanelFunc::copyToClipboardOrigin;
 
 ListPanelFunc::ListPanelFunc(ListPanel *parent) : QObject(parent),
         panel(parent), fileSystemP(0), urlManuallyEntered(false),
-        _isPaused(true), _refreshAfterPaused(true)
+        _isPaused(true), _refreshAfterPaused(true), _quickSizeCalculator(0)
 {
     history = new DirHistoryQueue(panel);
     delayTimer.setSingleShot(true);
@@ -106,12 +98,14 @@ ListPanelFunc::~ListPanelFunc()
         fileSystemP->deleteLater();
     }
     delete history;
+    if (_quickSizeCalculator)
+        _quickSizeCalculator->deleteLater();
 }
 
 bool ListPanelFunc::isSyncing(const QUrl &url)
 {
     if(otherFunc()->otherFunc() == this &&
-       panel->otherPanel()->gui->syncBrowseButton->state() == SYNCBROWSE_CD &&
+       panel->otherPanel()->gui->syncBrowseButton->isChecked() &&
        !otherFunc()->syncURL.isEmpty() &&
        otherFunc()->syncURL == url)
         return true;
@@ -123,12 +117,12 @@ void ListPanelFunc::openFileNameInternal(const QString &name, bool externallyExe
 {
     if (name == "..") {
         dirUp();
-        return ;
+        return;
     }
 
     FileItem *fileitem = files()->getFileItem(name);
     if (fileitem == 0)
-        return ;
+        return;
 
     QUrl url = files()->getUrl(name);
 
@@ -187,14 +181,15 @@ QUrl ListPanelFunc::cleanPath(const QUrl &urlIn)
 void ListPanelFunc::openUrl(const QUrl &url, const QString& nameToMakeCurrent,
                             bool manuallyEntered)
 {
-    if (panel->syncBrowseButton->state() == SYNCBROWSE_CD) {
+    qDebug() << "URL=" << url.toDisplayString() << "; name to current=" << nameToMakeCurrent;
+    if (panel->syncBrowseButton->isChecked()) {
         //do sync-browse stuff....
         if(syncURL.isEmpty())
             syncURL = panel->otherPanel()->virtualPath();
 
         QString relative = QDir(panel->virtualPath().path() + '/').relativeFilePath(url.path());
         syncURL.setPath(QDir::cleanPath(syncURL.path() + '/' + relative));
-        panel->otherPanel()->gui->setLocked(false);
+        panel->otherPanel()->gui->setTabState(ListPanel::TabState::DEFAULT);
         otherFunc()->openUrlInternal(syncURL, nameToMakeCurrent, false, false);
     }
     openUrlInternal(url, nameToMakeCurrent, false, manuallyEntered);
@@ -219,7 +214,11 @@ void ListPanelFunc::openUrlInternal(const QUrl &url, const QString& nameToMakeCu
 
     urlManuallyEntered = manuallyEntered;
 
-    history->add(cleanUrl, nameToMakeCurrent);
+    const QString currentItem = history->currentUrl().path() == cleanUrl.path()
+                                ? history->currentItem()
+                                : nameToMakeCurrent;
+
+    history->add(cleanUrl, currentItem);
 
     if(immediately)
         doRefresh();
@@ -229,7 +228,7 @@ void ListPanelFunc::openUrlInternal(const QUrl &url, const QString& nameToMakeCu
 
 void ListPanelFunc::refresh()
 {
-    panel->inlineRefreshCancel();
+    panel->cancelProgress();
     delayTimer.start(0); // to avoid qApp->processEvents() deadlock situaltion
 }
 
@@ -251,10 +250,10 @@ void ListPanelFunc::doRefresh()
     if(!url.isValid()) {
         panel->slotStartUpdate(true);  // refresh the panel
         urlManuallyEntered = false;
-        return ;
+        return;
     }
 
-    panel->inlineRefreshCancel();
+    panel->cancelProgress();
 
     // if we are not refreshing to current URL
     const bool isEqualUrl = files()->currentDirectory().matches(url, QUrl::StripTrailingSlash);
@@ -284,36 +283,32 @@ void ListPanelFunc::doRefresh()
         fileSystemP = fileSystem; // v != 0 so this is safe
     } else {
         if (fileSystemP->isRefreshing()) {
+            // TODO remove busy waiting here
             delayTimer.start(100); /* if filesystem is busy try refreshing later */
             return;
         }
     }
     // (re)connect filesystem signals
     disconnect(files(), 0, panel, 0);
-    connect(files(), SIGNAL(refreshDone(bool)), panel, SLOT(slotStartUpdate(bool)));
+    connect(files(), &DirListerInterface::scanDone, panel, &ListPanel::slotStartUpdate);
     connect(files(), &FileSystem::fileSystemInfoChanged, panel, &ListPanel::updateFilesystemStats);
-    connect(files(), SIGNAL(refreshJobStarted(KIO::Job*)),
-            panel, SLOT(slotJobStarted(KIO::Job*)));
+    connect(files(), &FileSystem::refreshJobStarted, panel, &ListPanel::slotRefreshJobStarted);
     connect(files(), SIGNAL(error(QString)),
             panel, SLOT(slotFilesystemError(QString)));
 
     panel->view->setFiles(files());
 
-    if(!history->currentItem().isEmpty() && isEqualUrl) {
-        // if the url we're refreshing into is the current one, then the
-        // partial refresh will not generate the needed signals to actually allow the
-        // view to use nameToMakeCurrent. do it here instead (patch by Thomas Jarosch)
-        panel->view->setCurrentItem(history->currentItem());
-        panel->view->makeItemVisible(panel->view->getCurrentKrViewItem());
+    if (!isEqualUrl || !panel->view->getCurrentKrViewItem()) {
+        // set current item after refresh from history, if there is none yet
+        panel->view->setNameToMakeCurrent(history->currentItem());
     }
-    panel->view->setNameToMakeCurrent(history->currentItem());
 
     // workaround for detecting panel deletion while filesystem is refreshing
     QPointer<ListPanel> panelSave = panel;
     // NOTE: this is blocking. Returns false on error or interruption (cancel requested or panel
     // was deleted)
-    const bool refreshed = fileSystemP->refresh(url);
-    if (refreshed) {
+    const bool scanned = fileSystemP->refresh(url);
+    if (scanned) {
         // update the history and address bar, as the actual url might differ from the one requested
         history->setCurrentUrl(fileSystemP->currentDirectory());
         panel->setNavigatorUrl(fileSystemP->currentDirectory());
@@ -331,7 +326,7 @@ void ListPanelFunc::doRefresh()
 
     // see if the open url operation failed, and if so,
     // put the attempted url in the navigator bar and let the user change it
-    if (!refreshed) {
+    if (!scanned) {
         if(isSyncing(url))
             panel->otherPanel()->gui->syncBrowseButton->setChecked(false);
         else if(urlManuallyEntered) {
@@ -364,18 +359,18 @@ void ListPanelFunc::redirectLink()
 {
     if (!files()->isLocal()) {
         KMessageBox::sorry(krMainWindow, i18n("You can edit links only on local file systems"));
-        return ;
+        return;
     }
 
     FileItem *fileitem = files()->getFileItem(panel->getCurrentName());
     if (!fileitem)
-        return ;
+        return;
 
     QString file = fileitem->getUrl().path();
     QString currentLink = fileitem->getSymDest();
     if (currentLink.isEmpty()) {
         KMessageBox::sorry(krMainWindow, i18n("The current file is not a link, so it cannot be redirected."));
-        return ;
+        return;
     }
 
     // ask the user for a new destination
@@ -385,16 +380,16 @@ void ListPanelFunc::redirectLink()
 
     // if the user canceled - quit
     if (!ok || newLink == currentLink)
-        return ;
+        return;
     // delete the current link
     if (unlink(file.toLocal8Bit()) == -1) {
         KMessageBox::sorry(krMainWindow, i18n("Cannot remove old link: %1", file));
-        return ;
+        return;
     }
     // try to create a new symlink
     if (symlink(newLink.toLocal8Bit(), file.toLocal8Bit()) == -1) {
         KMessageBox:: /* --=={ Patch by Heiner <h.eichmann@gmx.de> }==-- */sorry(krMainWindow, i18n("Failed to create a new link: %1", file));
-        return ;
+        return;
     }
 }
 
@@ -443,15 +438,15 @@ void ListPanelFunc::view()
 {
     QString fileName = panel->getCurrentName();
     if (fileName.isNull())
-        return ;
+        return;
 
     // if we're trying to view a directory, just exit
     FileItem *fileitem = files()->getFileItem(fileName);
     if (!fileitem || fileitem->isDir())
-        return ;
+        return;
     if (!fileitem->isReadable()) {
         KMessageBox::sorry(0, i18n("No permissions to view this file."));
-        return ;
+        return;
     }
     // call KViewer.
     KrViewer::view(files()->getUrl(fileName));
@@ -489,7 +484,7 @@ void ListPanelFunc::edit()
     if (tmp.isDir()) {
         KMessageBox::sorry(krMainWindow, i18n("You cannot edit a folder"));
         fileToCreate = QUrl();
-        return ;
+        return;
     }
 
     if (!tmp.isReadable()) {
@@ -553,6 +548,19 @@ void ListPanelFunc::copyFiles(bool enqueue, bool move)
 
     QUrl destination = panel->otherPanel()->virtualPath();
 
+    bool fullDestPath = false;
+    if (fileNames.count() == 1 && otherFunc()->files()->type() != FileSystem::FS_VIRTUAL) {
+        FileItem *item = files()->getFileItem(fileNames[0]);
+        if (item && !item->isDir()) {
+            fullDestPath = true;
+            // add original filename to destination
+            destination.setPath(QDir(destination.path()).filePath(item->getUrl().fileName()));
+        }
+    }
+    if (!fullDestPath) {
+        destination = FileSystem::ensureTrailingSlash(destination);
+    }
+
     const KConfigGroup group(krConfig, "Advanced");
     const bool showDialog = move ? group.readEntry("Confirm Move", _ConfirmMove) :
                                    group.readEntry("Confirm Copy", _ConfirmCopy);
@@ -595,7 +603,7 @@ void ListPanelFunc::copyFiles(bool enqueue, bool move)
         destination = FileSystem::ensureTrailingSlash(destination);
     }
 
-    KIO::CopyJob::CopyMode mode = move ? KIO::CopyJob::Move : KIO::CopyJob::Copy;
+    const KIO::CopyJob::CopyMode mode = move ? KIO::CopyJob::Move : KIO::CopyJob::Copy;
     FileSystemProvider::instance().startCopyFiles(fileUrls, destination, mode, true, startMode);
 
     if(KConfigGroup(krConfig, "Look&Feel").readEntry("UnselectBeforeOperation", _UnselectBeforeOperation)) {
@@ -632,44 +640,32 @@ void ListPanelFunc::mkdir()
     if (!suggestedName.isEmpty() && !files()->getFileItem(suggestedName)->isDir())
         suggestedName = QFileInfo(suggestedName).completeBaseName();
 
-    QString dirName = QInputDialog::getText(krMainWindow, i18n("New folder"), i18n("Folder's name:"), QLineEdit::Normal, suggestedName);
+    const QString dirName = QInputDialog::getText(krMainWindow, i18n("New folder"), i18n("Folder's name:"), QLineEdit::Normal, suggestedName);
 
-    // if the user canceled - quit
-    if (dirName.isEmpty())
-        return ;
+    const QString firstName = dirName.section('/', 0, 0, QString::SectionIncludeLeadingSep);
 
-    QStringList dirTree = dirName.split('/');
+    // if the user canceled or the name was composed of slashes - quit
+    if (!dirName.startsWith('/') && firstName.isEmpty()) {
+        return;
+    }
 
-    for (QStringList::Iterator it = dirTree.begin(); it != dirTree.end(); ++it) {
-        if (*it == ".")
-            continue;
-        if (*it == "..") {
-            immediateOpenUrl(QUrl::fromUserInput(*it, QString(), QUrl::AssumeLocalFile));
-            continue;
-        }
-        // check if the name is already taken
-        if (files()->getFileItem(*it)) {
-            // if it is the last dir to be created - quit
-            if (*it == dirTree.last()) {
-                KMessageBox::sorry(krMainWindow, i18n("A folder or a file with this name already exists."));
-                return ;
-            }
-            // else go into this dir
-            else {
-                immediateOpenUrl(QUrl::fromUserInput(*it, QString(), QUrl::AssumeLocalFile));
-                continue;
-            }
-        }
+    // notify user about existing folder if only single directory was given
+    if (!dirName.contains('/') && files()->getFileItem(firstName)) {
+        // focus the existing directory
+        panel->view->setCurrentItem(firstName);
+        // show error message
+        KMessageBox::sorry(krMainWindow, i18n("A folder or a file with this name already exists."));
+        return;
+    }
 
-        panel->view->setNameToMakeCurrent(*it);
-        // as always - the filesystem does the job
-        files()->mkDir(*it);
-        if (dirTree.count() > 1)
-            immediateOpenUrl(QUrl::fromUserInput(*it, QString(), QUrl::AssumeLocalFile));
-    } // for
+    // focus new directory when next refresh happens
+    panel->view->setNameToMakeCurrent(firstName);
+
+    // create new directory (along with underlying directories if necessary)
+    files()->mkDir(dirName);
 }
 
-void ListPanelFunc::defaultDeleteFiles(bool invert)
+void ListPanelFunc::defaultOrAlternativeDeleteFiles(bool invert)
 {
     const bool trash = KConfigGroup(krConfig, "General").readEntry("Move To Trash", _MoveToTrash);
     deleteFiles(trash != invert);
@@ -684,7 +680,7 @@ void ListPanelFunc::deleteFiles(bool moveToTrash)
     }
 
     // first get the selected file names list
-    QStringList fileNames = panel->getSelectedNames();
+    const QStringList fileNames = panel->getSelectedNames();
     if (fileNames.isEmpty())
         return;
 
@@ -692,6 +688,33 @@ void ListPanelFunc::deleteFiles(bool moveToTrash)
     moveToTrash = moveToTrash && files()->canMoveToTrash(fileNames);
 
     // now ask the user if he/she is sure:
+
+    const QList<QUrl> confirmedUrls = confirmDeletion(
+        files()->getUrls(fileNames), moveToTrash, files()->type() == FileSystem::FS_VIRTUAL, false);
+
+    if (confirmedUrls.isEmpty())
+        return; // nothing to delete
+
+    // after the delete return the cursor to the first unmarked
+    // file above the current item;
+    panel->prepareToDelete();
+
+    // let the filesystem do the job...
+    QStringList confirmedFileNames;
+    for (QUrl fileUrl : confirmedUrls) {
+        confirmedFileNames.append(fileUrl.fileName());
+    }
+    files()->deleteFiles(confirmedFileNames, moveToTrash);
+}
+
+QList<QUrl> ListPanelFunc::confirmDeletion(const QList<QUrl> &urls, bool moveToTrash,
+                                           bool virtualFS, bool showPath)
+{
+    QStringList files;
+    for (QUrl fileUrl : urls) {
+        files.append(showPath ? fileUrl.toDisplayString(QUrl::PreferLocalFile) : fileUrl.fileName());
+    }
+
     const KConfigGroup advancedGroup(krConfig, "Advanced");
     if (advancedGroup.readEntry("Confirm Delete", _ConfirmDelete)) {
         QString s; // text
@@ -699,77 +722,79 @@ void ListPanelFunc::deleteFiles(bool moveToTrash)
 
         if (moveToTrash) {
             s = i18np("Do you really want to move this item to the trash?",
-                      "Do you really want to move these %1 items to the trash?", fileNames.count());
+                      "Do you really want to move these %1 items to the trash?", files.count());
             b = KGuiItem(i18n("&Trash"));
-        } else if (files()->type() == FileSystem::FS_VIRTUAL) {
+        } else if (virtualFS) {
             s = i18np("<qt>Do you really want to delete this item <b>physically</b> (not just "
                       "removing it from the virtual items)?</qt>",
                       "<qt>Do you really want to delete these %1 items <b>physically</b> (not just "
                       "removing them from the virtual items)?</qt>",
-                      fileNames.count());
+                      files.count());
             b = KStandardGuiItem::del();
         } else {
             s = i18np("Do you really want to delete this item?",
-                      "Do you really want to delete these %1 items?", fileNames.count());
+                      "Do you really want to delete these %1 items?", files.count());
             b = KStandardGuiItem::del();
         }
 
         // show message
         // note: i'm using continue and not yes/no because the yes/no has cancel as default button
-        if (KMessageBox::warningContinueCancelList(krMainWindow, s, fileNames, i18n("Warning"),
-                                                   b) != KMessageBox::Continue)
-            return;
+        if (KMessageBox::warningContinueCancelList(krMainWindow, s, files, i18n("Warning"),
+                                                   b) != KMessageBox::Continue) {
+            return QList<QUrl>();
+        }
     }
 
     // we want to warn the user about non empty dir
-    bool emptyDirVerify = advancedGroup.readEntry("Confirm Unempty Dir", _ConfirmUnemptyDir);
-    // TODO only local fs supported
-    emptyDirVerify &= files()->isLocal();
+    const bool emptyDirVerify = advancedGroup.readEntry("Confirm Unempty Dir", _ConfirmUnemptyDir);
 
+    QList<QUrl> toDelete;
     if (emptyDirVerify) {
-        QMutableStringListIterator it(fileNames);
-        while (it.hasNext()) {
-            const QString fileName = it.next();
-            FileItem *fileItem = files()->getFileItem(fileName);
-            if (fileItem && !fileItem->isSymLink() && fileItem->isDir()) {
+        QSet<QUrl> confirmedFiles = urls.toSet();
+        for (QUrl fileUrl : urls) {
+            if (!fileUrl.isLocalFile()) {
+                continue; // TODO only local fs supported
+            }
+
+            const QString filePath = fileUrl.toLocalFile();
+            QFileInfo fileInfo(filePath);
+            if (fileInfo.isDir() && !fileInfo.isSymLink()) {
                 // read local dir...
-                const QDir dir(fileItem->getUrl().toLocalFile());
+                const QDir dir(filePath);
                 if (!dir.entryList(QDir::AllEntries | QDir::System | QDir::Hidden |
                                    QDir::NoDotAndDotDot).isEmpty()) {
+
                     // ...is not empty, ask user
+                    const QString fileString = showPath ? filePath : fileUrl.fileName();
                     const KMessageBox::ButtonCode result = KMessageBox::warningYesNoCancel(
                         krMainWindow,
-                        i18n("<qt><p>Folder <b>%1</b> is not empty.</p>", fileName) +
+                        i18n("<qt><p>Folder <b>%1</b> is not empty.</p>", fileString) +
                             (moveToTrash ? i18n("<p>Skip this one or trash all?</p></qt>") :
                                            i18n("<p>Skip this one or delete all?</p></qt>")),
                         QString(), KGuiItem(i18n("&Skip")),
                         KGuiItem(moveToTrash ? i18n("&Trash All") : i18n("&Delete All")));
                     if (result == KMessageBox::Yes) {
-                        it.remove(); // skip
+                        confirmedFiles.remove(fileUrl); // skip this dir
                     } else if (result == KMessageBox::No) {
                         break; // accept all remaining
                     } else {
-                        return; // cancel
+                        return QList<QUrl>(); // cancel
                     }
                 }
             }
         }
-        if (fileNames.isEmpty())
-            return; // nothing to delete
+        toDelete = confirmedFiles.toList();
+    } else {
+        toDelete = urls;
     }
 
-    // after the delete return the cursor to the first unmarked
-    // file above the current item;
-    panel->prepareToDelete();
-
-    // let the filesystem do the job...
-    files()->deleteFiles(fileNames, moveToTrash);
+    return toDelete;
 }
 
 void ListPanelFunc::removeVirtualFiles()
 {
     if (files()->type() != FileSystem::FS_VIRTUAL) {
-        krOut << "filesystem not virtual";
+        qWarning() << "filesystem not virtual";
         return;
     }
 
@@ -797,7 +822,7 @@ void ListPanelFunc::goInside(const QString& name)
 
 void ListPanelFunc::runCommand(QString cmd)
 {
-    krOut << "Run command: " << cmd;
+    qDebug() << "command=" << cmd;
     const QString workdir = panel->virtualPath().isLocalFile() ?
             panel->virtualPath().path() : QDir::homePath();
     if(!KRun::runCommand(cmd, krMainWindow, workdir))
@@ -806,7 +831,7 @@ void ListPanelFunc::runCommand(QString cmd)
 
 void ListPanelFunc::runService(const KService &service, QList<QUrl> urls)
 {
-    krOut << "Run service: " << service.name();
+    qDebug() << "service name=" << service.name();
     KIO::DesktopExecParser parser(service, urls);
     QStringList args = parser.resultingArguments();
     if (!args.isEmpty())
@@ -989,11 +1014,35 @@ void ListPanelFunc::calcSpace()
         panel->view->getSelectedItems(&fileNames);
     }
 
-    SizeCalculator *sizeCalculator = new SizeCalculator(files()->getUrls(fileNames));
+    SizeCalculator *sizeCalculator = createAndConnectSizeCalculator(files()->getUrls(fileNames));
+    KrCalcSpaceDialog::showDialog(panel, sizeCalculator);
+}
+
+void ListPanelFunc::quickCalcSpace()
+{
+    const QString currentName = panel->getCurrentName();
+    if (currentName.isEmpty()) {
+        // current file is ".." dummy, do a verbose calcSpace
+        calcSpace();
+        return;
+    }
+
+    if (!_quickSizeCalculator) {
+        _quickSizeCalculator = createAndConnectSizeCalculator(QList<QUrl>());
+        panel->connectQuickSizeCalculator(_quickSizeCalculator);
+    }
+
+    _quickSizeCalculator->add(files()->getUrl(currentName));
+}
+
+
+SizeCalculator *ListPanelFunc::createAndConnectSizeCalculator(const QList<QUrl> &urls)
+{
+    SizeCalculator *sizeCalculator = new SizeCalculator(urls);
     connect(sizeCalculator, &SizeCalculator::calculated, this, &ListPanelFunc::slotSizeCalculated);
     connect(sizeCalculator, &SizeCalculator::finished, panel, &ListPanel::slotUpdateTotals);
     connect(this, &ListPanelFunc::destroyed, sizeCalculator, &SizeCalculator::deleteLater);
-    KrCalcSpaceDialog::showDialog(panel, sizeCalculator);
+    return sizeCalculator;
 }
 
 void ListPanelFunc::slotSizeCalculated(const QUrl &url, KIO::filesize_t size)
@@ -1021,34 +1070,40 @@ void ListPanelFunc::newFTPconnection()
     QUrl url = KRSpWidgets::newFTP();
     // if the user canceled - quit
     if (url.isEmpty())
-        return ;
+        return;
 
     panel->_actions->actFTPDisconnect->setEnabled(true);
+
+    qDebug() << "URL=" << url.toDisplayString();
+
     openUrl(url);
 }
 
 void ListPanelFunc::properties()
 {
     const QStringList names = panel->getSelectedNames();
-    if (names.isEmpty())
+    if (names.isEmpty()) {
         return ;  // no names...
-    KFileItemList fi;
-
-    for (int i = 0 ; i < names.count() ; ++i) {
-        FileItem *fileitem = files()->getFileItem(names[i]);
-        if (!fileitem)
-            continue;
-        QUrl url = files()->getUrl(names[i]);
-        fi.push_back(KFileItem(fileitem->getEntry(), url));
     }
 
-    if (fi.isEmpty())
-        return ;
+    KFileItemList fileItems;
+
+    for (const QString name : names) {
+        FileItem *fileitem = files()->getFileItem(name);
+        if (!fileitem) {
+            continue;
+        }
+
+        fileItems.push_back(KFileItem(fileitem->getEntry(), files()->getUrl(name)));
+    }
+
+    if (fileItems.isEmpty())
+        return;
 
     // Show the properties dialog
-    KPropertiesDialog *dlg = new KPropertiesDialog(fi, krMainWindow);
-    connect(dlg, SIGNAL(applied()), SLOT(refresh()));
-    dlg->show();
+    KPropertiesDialog *dialog = new KPropertiesDialog(fileItems, krMainWindow);
+    connect(dialog, &KPropertiesDialog::applied, this, &ListPanelFunc::refresh);
+    dialog->show();
 }
 
 void ListPanelFunc::refreshActions()
@@ -1163,7 +1218,7 @@ void ListPanelFunc::pasteFromClipboard()
 
     QList<QUrl> urls = data->urls();
     if (urls.isEmpty())
-        return ;
+        return;
 
     if(origin && KConfigGroup(krConfig, "Look&Feel").readEntry("UnselectBeforeOperation", _UnselectBeforeOperation)) {
         origin->panel->view->saveSelection();
@@ -1228,4 +1283,3 @@ bool ListPanelFunc::atHome()
 {
     return QUrl::fromLocalFile(QDir::homePath()).matches(panel->virtualPath(), QUrl::StripTrailingSlash);
 }
-
