@@ -1,32 +1,23 @@
-/***************************************************************************
-                                 krsearchdialog.cpp
-                             -------------------
-    copyright            : (C) 2001 by Shie Erlich & Rafi Yanai
-    email                : krusader@users.sourceforge.net
-    web site   : http://krusader.sourceforge.net
- ---------------------------------------------------------------------------
-  Description
- ***************************************************************************
-
-  A
-
-     db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-     88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-     88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-     88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-     88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-     YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                                     S o u r c e    F i l e
-
- ***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2001 Shie Erlich <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2001 Rafi Yanai <krusader@users.sourceforge.net>            *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #include "krsearchdialog.h"
 
@@ -45,37 +36,36 @@
 #include <QGridLayout>
 #include <QInputDialog>
 #include <QHBoxLayout>
-#include <QLabel>
 #include <QMenu>
-#include <QTabWidget>
 
 #include <KConfigCore/KConfig>
 #include <KI18n/KLocalizedString>
 #include <KWidgetsAddons/KMessageBox>
 
-#include "../krglobal.h"
-#include "../kractions.h"
-#include "../krservices.h"
-#include "../krslots.h"
-#include "../defaults.h"
-#include "../panelmanager.h"
-#include "../kicons.h"
-#include "../krusaderview.h"
+#include "krsearchmod.h"
 #include "../Dialogs/krdialogs.h"
 #include "../Dialogs/krspecialwidgets.h"
 #include "../Dialogs/krsqueezedtextlabel.h"
-#include "../FileSystem/virtualfilesystem.h"
+#include "../FileSystem/fileitem.h"
 #include "../FileSystem/krquery.h"
-#include "../KViewer/krviewer.h"
-#include "../Panel/krsearchbar.h"
-#include "../Panel/krview.h"
-#include "../Panel/krviewfactory.h"
-#include "../Panel/krviewitem.h"
-#include "../Panel/krpanel.h"
-#include "../Panel/panelfunc.h"
+#include "../FileSystem/virtualfilesystem.h"
 #include "../Filter/filtertabs.h"
 #include "../Filter/generalfilter.h"
-
+#include "../KViewer/krviewer.h"
+#include "../Panel/PanelView/krview.h"
+#include "../Panel/PanelView/krviewfactory.h"
+#include "../Panel/PanelView/krviewitem.h"
+#include "../Panel/krpanel.h"
+#include "../Panel/krsearchbar.h"
+#include "../Panel/panelfunc.h"
+#include "../defaults.h"
+#include "../kractions.h"
+#include "../krglobal.h"
+#include "../filelisticon.h"
+#include "../krservices.h"
+#include "../krslots.h"
+#include "../krusaderview.h"
+#include "../panelmanager.h"
 
 #define RESULTVIEW_TYPE 0
 
@@ -145,7 +135,7 @@ KrSearchDialog::KrSearchDialog(QString profile, QWidget* parent)
     KConfigGroup group(krConfig, "Search");
 
     setWindowTitle(i18n("Krusader::Search"));
-    setWindowIcon(QIcon::fromTheme("system-search"));
+    setWindowIcon(Icon("system-search"));
 
     QGridLayout* searchBaseLayout = new QGridLayout(this);
     searchBaseLayout->setSpacing(6);
@@ -160,30 +150,40 @@ KrSearchDialog::KrSearchDialog(QString profile, QWidget* parent)
     profileManager = new ProfileManager("SearcherProfile", this);
     buttonsLayout->addWidget(profileManager);
 
+    searchTextToClipboard = new QCheckBox(this);
+    searchTextToClipboard->setText(i18n("Query to clipboard"));
+    searchTextToClipboard->setToolTip(i18n("Place search text to clipboard when a found file is opened."));
+    searchTextToClipboard->setCheckState(static_cast<Qt::CheckState>(group.readEntry("QueryToClipboard", 0)));
+    connect(searchTextToClipboard, &QCheckBox::stateChanged, this, [=](int state) {
+        KConfigGroup group(krConfig, "Search");
+        group.writeEntry("QueryToClipboard", state);
+    });
+    buttonsLayout->addWidget(searchTextToClipboard);
+
     QSpacerItem* spacer = new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
     buttonsLayout->addItem(spacer);
 
     mainFeedToListBoxBtn = new QPushButton(this);
     mainFeedToListBoxBtn->setText(i18n("Feed to listbox"));
-    mainFeedToListBoxBtn->setIcon(QIcon::fromTheme("list-add"));
+    mainFeedToListBoxBtn->setIcon(Icon("list-add"));
     mainFeedToListBoxBtn->setEnabled(false);
     buttonsLayout->addWidget(mainFeedToListBoxBtn);
 
     mainSearchBtn = new QPushButton(this);
     mainSearchBtn->setText(i18n("Search"));
-    mainSearchBtn->setIcon(QIcon::fromTheme("edit-find"));
+    mainSearchBtn->setIcon(Icon("edit-find"));
     mainSearchBtn->setDefault(true);
     buttonsLayout->addWidget(mainSearchBtn);
 
     mainStopBtn = new QPushButton(this);
     mainStopBtn->setEnabled(false);
     mainStopBtn->setText(i18n("Stop"));
-    mainStopBtn->setIcon(QIcon::fromTheme("process-stop"));
+    mainStopBtn->setIcon(Icon("process-stop"));
     buttonsLayout->addWidget(mainStopBtn);
 
     mainCloseBtn = new QPushButton(this);
     mainCloseBtn->setText(i18n("Close"));
-    mainCloseBtn->setIcon(QIcon::fromTheme("dialog-close"));
+    mainCloseBtn->setIcon(Icon("dialog-close"));
     buttonsLayout->addWidget(mainCloseBtn);
 
     searchBaseLayout->addLayout(buttonsLayout, 1, 0);
@@ -480,8 +480,9 @@ void KrSearchDialog::executed(const QString &name)
         path = name.left(idx);
     }
     QUrl url(path);
-    if (url.scheme().isEmpty())
-        url.setScheme("file");
+    if (url.scheme().isEmpty()) {
+        url = QUrl::fromLocalFile(path);
+    }
     ACTIVE_FUNC->openUrl(url, fileName);
     showMinimized();
 }
@@ -523,13 +524,11 @@ void KrSearchDialog::keyPressEvent(QKeyEvent *e)
         if ((e->key() | e->modifiers()) == (Qt::CTRL | Qt::Key_I)) {
             searchBar->showBar(KrSearchBar::MODE_FILTER);
         } else if (e->key() == Qt::Key_F4) {
-            if (!generalFilter->containsText->currentText().isEmpty() && QApplication::clipboard()->text() != generalFilter->containsText->currentText())
-                QApplication::clipboard()->setText(generalFilter->containsText->currentText());
+            tryPlaceSearchQueryToClipboard();
             editCurrent();
             return;
         } else if (e->key() == Qt::Key_F3) {
-            if (!generalFilter->containsText->currentText().isEmpty() && QApplication::clipboard()->text() != generalFilter->containsText->currentText())
-                QApplication::clipboard()->setText(generalFilter->containsText->currentText());
+            tryPlaceSearchQueryToClipboard();
             viewCurrent();
             return;
         } else if (e->key() == Qt::Key_F10) {
@@ -596,7 +595,7 @@ void KrSearchDialog::contextMenu(const QPoint &pos)
 void KrSearchDialog::feedToListBox()
 {
     VirtualFileSystem virtFilesystem;
-    virtFilesystem.refresh(QUrl::fromLocalFile("/"));
+    virtFilesystem.scanDir(QUrl::fromLocalFile("/"));
 
     KConfigGroup group(krConfig, "Search");
     int listBoxNum = group.readEntry("Feed To Listbox Counter", 1);
@@ -633,8 +632,8 @@ void KrSearchDialog::feedToListBox()
 
     isBusy = true;
 
-    QUrl url = QUrl(QString("virt:/") + fileSystemName);
-    virtFilesystem.refresh(url);
+    const QUrl url = QUrl(QString("virt:/") + fileSystemName);
+    virtFilesystem.scanDir(url);
     virtFilesystem.addFiles(urlList);
     virtFilesystem.setMetaInformation(queryName);
     //ACTIVE_FUNC->openUrl(url);
@@ -655,9 +654,17 @@ void KrSearchDialog::copyToClipBoard()
         return;
 
     QMimeData *mimeData = new QMimeData;
-    mimeData->setImageData(FL_LOADICON("file"));
+    mimeData->setImageData(FileListIcon("file").pixmap());
     mimeData->setUrls(urls);
 
     QApplication::clipboard()->setMimeData(mimeData, QClipboard::Clipboard);
 }
 
+void KrSearchDialog::tryPlaceSearchQueryToClipboard()
+{
+    if (searchTextToClipboard->isChecked()
+            && !generalFilter->containsText->currentText().isEmpty()
+            && QApplication::clipboard()->text() != generalFilter->containsText->currentText()) {
+        QApplication::clipboard()->setText(generalFilter->containsText->currentText());
+    }
+}
