@@ -2,20 +2,22 @@
  * Copyright (C) 2004 Shie Erlich <erlich@users.sourceforge.net>             *
  * Copyright (C) 2004 Rafi Yanai <yanai@users.sourceforge.net>               *
  * Copyright (C) 2006 Jonas Bähr <jonas.baehr@web.de>                        *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
  *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
  * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
+ * the Free Software Foundation, either version 2 of the License, or         *
  * (at your option) any later version.                                       *
  *                                                                           *
- * This package is distributed in the hope that it will be useful,           *
+ * Krusader is distributed in the hope that it will be useful,               *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
  * GNU General Public License for more details.                              *
  *                                                                           *
  * You should have received a copy of the GNU General Public License         *
- * along with this package; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
  *****************************************************************************/
 
 #include "kraction.h"
@@ -54,6 +56,7 @@
 #include "useraction.h"
 #include "../GUI/terminaldock.h"
 #include "../krglobal.h"
+#include "../icon.h"
 #include "../krusaderview.h"
 #include "../krservices.h"
 #include "../defaults.h"
@@ -384,7 +387,7 @@ bool KrAction::isAvailable(const QUrl &currentURL)
     if (! _showonlyProtocol.empty()) {
         available = false;
         for (QStringList::Iterator it = _showonlyProtocol.begin(); it != _showonlyProtocol.end(); ++it) {
-            //qDebug() << "KrAction::isAvailable currendProtocol: " << currentURL.scheme() << " =?= " << *it << endl;
+            //qDebug() << "KrAction::isAvailable currendProtocol: " << currentURL.scheme() << " =?= " << *it;
             if (currentURL.scheme() == *it) {    // FIXME remove trailing slashes at the xml-parsing (faster because done only once)
                 available = true;
                 break;
@@ -479,7 +482,7 @@ bool KrAction::xmlRead(const QDomElement& element)
                 setToolTip(i18n(e.text().toUtf8().constData()));
             else
                 if (e.tagName() == "icon")
-                    setIcon(QIcon::fromTheme(_iconName = e.text()));
+                    setIcon(Icon(_iconName = e.text()));
                 else
                     if (e.tagName() == "category")
                         setCategory(i18n(e.text().toUtf8().constData()));
@@ -502,7 +505,7 @@ bool KrAction::xmlRead(const QDomElement& element)
 
                                             // unknown but not empty
                                             if (! e.tagName().isEmpty())
-                                                krOut << "KrAction::xmlRead() - unrecognized tag found: <action name=\"" << objectName() << "\"><" << e.tagName() << ">" << endl;
+                                                qWarning() << "KrAction::xmlRead() - unrecognized tag found: <action name=\"" << objectName() << "\"><" << e.tagName() << ">";
 
     } // for ( QDomNode node = action->firstChild(); !node.isNull(); node = node.nextSibling() )
 
@@ -572,7 +575,7 @@ void KrAction::readCommand(const QDomElement& element)
         else if (attr == "embedded_terminal")
             setExecType(RunInTE);
         else
-            krOut << "KrAction::readCommand() - unrecognized attribute value found: <action name=\"" << objectName() << "\"><command executionmode=\"" << attr << "\"" << endl;
+            qWarning() << "KrAction::readCommand() - unrecognized attribute value found: <action name=\"" << objectName() << "\"><command executionmode=\"" << attr << "\"";
 
     attr = element.attribute("accept", "local");   // default: "local"
     if (attr == "local")
@@ -580,7 +583,7 @@ void KrAction::readCommand(const QDomElement& element)
     else if (attr == "url")
         setAcceptURLs(true);
     else
-        krOut << "KrAction::readCommand() - unrecognized attribute value found: <action name=\"" << objectName() << "\"><command accept=\"" << attr << "\"" << endl;
+        qWarning() << "KrAction::readCommand() - unrecognized attribute value found: <action name=\"" << objectName() << "\"><command accept=\"" << attr << "\"";
 
     attr = element.attribute("confirmexecution", "false");   // default: "false"
     if (attr == "true")
@@ -651,7 +654,7 @@ void KrAction::readAvailability(const QDomElement& element)
                     if (e.tagName() == "filename")
                         showlist = & _showonlyFile;
                     else {
-                        krOut << "KrAction::readAvailability() - unrecognized element found: <action name=\"" << objectName() << "\"><availability><" << e.tagName() << ">" << endl;
+                        qWarning() << "KrAction::readAvailability() - unrecognized element found: <action name=\"" << objectName() << "\"><availability><" << e.tagName() << ">";
                         showlist = 0;
                     }
 
