@@ -1,27 +1,31 @@
 /*****************************************************************************
  * Copyright (C) 2002 Shie Erlich <erlich@users.sourceforge.net>             *
  * Copyright (C) 2002 Rafi Yanai <yanai@users.sourceforge.net>               *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
  *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
  * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
+ * the Free Software Foundation, either version 2 of the License, or         *
  * (at your option) any later version.                                       *
  *                                                                           *
- * This package is distributed in the hope that it will be useful,           *
+ * Krusader is distributed in the hope that it will be useful,               *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
  * GNU General Public License for more details.                              *
  *                                                                           *
  * You should have received a copy of the GNU General Public License         *
- * along with this package; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
  *****************************************************************************/
 
 #include "krservices.h"
 
 // QtCore
 #include <QDir>
+#include <QSet>
 #include <QTextStream>
+#include <QtGlobal>
 
 #include <KConfigCore/KSharedConfig>
 #include <KIOCore/KProtocolManager>
@@ -37,6 +41,8 @@ QSet<QString> KrServices::isoArchiveMimetypes = QSet<QString>::fromList(KProtoco
 QSet<QString> KrServices::isoArchiveMimetypes;
 #endif
 
+QString KrServices::GLOBAL_MESSAGE_PATTERN = "%{time hh:mm:ss.zzz}-%{type} %{category} %{function}@%{line} # %{message}";
+
 QSet<QString> KrServices::generateKrarcArchiveMimetypes()
 {
     // Hard-code these proven mimetypes openable by krarc protocol.
@@ -175,7 +181,7 @@ QString KrServices::quote(QString name)
     if (!name.contains('\''))
         return '\'' + name + '\'';
     if (!name.contains('"') && !name.contains('$'))
-        return '\"' + name + '\'';
+        return '\"' + name + '\"';
     return escape(name);
 }
 
@@ -293,3 +299,21 @@ QString KrServices::urlToLocalPath(const QUrl &url)
 #endif
     return path;
 }
+
+static bool s_withDebugMessages;
+static QtMessageHandler s_defaultMessageHandler;
+
+void KrServices::setGlobalKrMessageHandler(bool withDebugMessages)
+{
+    s_withDebugMessages = withDebugMessages;
+    s_defaultMessageHandler = qInstallMessageHandler(0);
+    qInstallMessageHandler(&krMessageHandler);
+}
+
+void KrServices::krMessageHandler(QtMsgType type, const QMessageLogContext &context, const QString &msg)
+{
+    // filter debug if not enabled
+    if (type != QtDebugMsg || s_withDebugMessages) {
+        s_defaultMessageHandler(type, context, msg);
+    }
+}
