@@ -1,32 +1,23 @@
-/***************************************************************************
-                                 krslots.cpp
-                             -------------------
-    copyright            : (C) 2001 by Shie Erlich & Rafi Yanai
-    email                : krusader@users.sourceforge.net
-    web site   : http://krusader.sourceforge.net
- ---------------------------------------------------------------------------
-  Description
- ***************************************************************************
-
-  A
-
-     db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
-     88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
-     88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
-     88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
-     88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
-     YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
-
-                                                     S o u r c e    F i l e
-
- ***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*****************************************************************************
+ * Copyright (C) 2001 Shie Erlich <krusader@users.sourceforge.net>           *
+ * Copyright (C) 2001 Rafi Yanai <krusader@users.sourceforge.net>            *
+ * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ *                                                                           *
+ * This file is part of Krusader [https://krusader.org].                     *
+ *                                                                           *
+ * Krusader is free software: you can redistribute it and/or modify          *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 2 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * Krusader is distributed in the hope that it will be useful,               *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with Krusader.  If not, see [http://www.gnu.org/licenses/].         *
+ *****************************************************************************/
 
 #include "krslots.h"
 
@@ -46,7 +37,6 @@
 #include <KConfigCore/KSharedConfig>
 #include <KCoreAddons/KShell>
 #include <KI18n/KLocalizedString>
-#include <KIconThemes/KIconLoader>
 #include <KWidgetsAddons/KToggleAction>
 #include <KWidgetsAddons/KMessageBox>
 
@@ -55,45 +45,47 @@
 #include "KrJS/krjs.h"
 #endif
 
-#include "KViewer/krviewer.h"
-#include "Panel/krviewfactory.h"
-#include "krusader.h"
-#include "kractions.h"
-#include "krusaderview.h"
-#include "Panel/listpanel.h"
-#include "Panel/krselectionmode.h"
-#include "Dialogs/krdialogs.h"
-#include "Dialogs/krspwidgets.h"
-#include "GUI/krusaderstatus.h"
-#include "Panel/panelfunc.h"
-#include "Konfigurator/konfigurator.h"
-#include "MountMan/kmountman.h"
 #include "defaults.h"
-#include "GUI/kfnkeys.h"
-#include "GUI/kcmdline.h"
-#include "GUI/terminaldock.h"
-#include "GUI/syncbrowsebutton.h"
-#include "GUI/mediabutton.h"
-#include "GUI/dirhistorybutton.h"
-#include "FileSystem/krquery.h"
-#include "Search/krsearchmod.h"
-#include "Search/krsearchdialog.h"
-#include "Locate/locate.h"
-#include "FileSystem/filesystem.h"
-#include "FileSystem/fileitem.h"
-#include "panelmanager.h"
-#include "Splitter/splittergui.h"
-#include "Splitter/splitter.h"
-#include "Splitter/combiner.h"
-#include "ActionMan/actionman.h"
-#include "Panel/panelpopup.h"
-#include "Dialogs/krspecialwidgets.h"
-#include "DiskUsage/diskusagegui.h"
+#include "icon.h"
+#include "kractions.h"
 #include "krservices.h"
-#include "Panel/krviewitem.h"
 #include "krtrashhandler.h"
-#include "BookMan/krbookmarkhandler.h"
+#include "krusader.h"
+#include "krusaderview.h"
+#include "panelmanager.h"
+
+#include "ActionMan/actionman.h"
 #include "BookMan/krbookmarkbutton.h"
+#include "BookMan/krbookmarkhandler.h"
+#include "Dialogs/krdialogs.h"
+#include "Dialogs/krspecialwidgets.h"
+#include "Dialogs/krspwidgets.h"
+#include "DiskUsage/diskusagegui.h"
+#include "FileSystem/fileitem.h"
+#include "FileSystem/filesystem.h"
+#include "FileSystem/krquery.h"
+#include "GUI/dirhistorybutton.h"
+#include "GUI/kcmdline.h"
+#include "GUI/kfnkeys.h"
+#include "GUI/krusaderstatus.h"
+#include "GUI/mediabutton.h"
+#include "GUI/terminaldock.h"
+#include "KViewer/krviewer.h"
+#include "Konfigurator/konfigurator.h"
+#include "Locate/locate.h"
+#include "MountMan/kmountman.h"
+#include "Panel/PanelView/krselectionmode.h"
+#include "Panel/PanelView/krview.h"
+#include "Panel/PanelView/krviewfactory.h"
+#include "Panel/PanelView/krviewitem.h"
+#include "Panel/listpanel.h"
+#include "Panel/panelfunc.h"
+#include "Panel/sidebar.h"
+#include "Search/krsearchdialog.h"
+#include "Search/krsearchmod.h"
+#include "Splitter/combiner.h"
+#include "Splitter/splitter.h"
+#include "Splitter/splittergui.h"
 
 #ifdef SYNCHRONIZER_ENABLED
     #include "Synchronizer/synchronizergui.h"
@@ -271,14 +263,14 @@ void KRslots::toggleTerminal()
     MAIN_VIEW->setTerminalEmulator(KrActions::actToggleTerminal->isChecked());
 }
 
-void KRslots::insertFileName(bool full_path)
+void KRslots::insertFileName(bool fullPath)
 {
     QString filename = ACTIVE_VIEW->getCurrentItem();
     if (filename.isEmpty()) {
         return;
     }
 
-    if (full_path) {
+    if (fullPath) {
         const QString path = FileSystem::ensureTrailingSlash(ACTIVE_PANEL->virtualPath())
                                  .toDisplayString(QUrl::PreferLocalFile);
         filename = path + filename;
@@ -293,7 +285,7 @@ void KRslots::insertFileName(bool full_path)
         MAIN_VIEW->cmdLine()->setText(current + filename);
         MAIN_VIEW->cmdLine()->setFocus();
     } else if (MAIN_VIEW->terminalDock()->isTerminalVisible()) {
-        filename = QChar(' ') + filename + QChar(' ');
+        filename = ' ' + filename + ' ';
         MAIN_VIEW->terminalDock()->sendInput(filename, false);
         MAIN_VIEW->terminalDock()->setFocus();
     }
@@ -336,15 +328,18 @@ void KRslots::configChanged(bool isGUIRestartNeeded)
         krApp->setUpdatesEnabled(true);
     }
 
+    krApp->setTray();
+
     // really ugly, but reload the Fn keys just in case - csaba: any better idea?
     MAIN_VIEW->fnKeys()->updateShortcuts();
 
-    bool showHidden = KConfigGroup(krConfig, "Look&Feel").readEntry("Show Hidden", KrActions::actToggleHidden->isChecked());
+    const bool showHidden = KConfigGroup(krConfig, "Look&Feel")
+                                .readEntry("Show Hidden", KrActions::actToggleHidden->isChecked());
 
     if (showHidden != KrActions::actToggleHidden->isChecked()) {
         KrActions::actToggleHidden->setChecked(showHidden);
-        MAIN_VIEW->leftManager()->refreshAllTabs();
-        MAIN_VIEW->rightManager()->refreshAllTabs();
+        MAIN_VIEW->leftManager()->reloadConfig();
+        MAIN_VIEW->rightManager()->reloadConfig();
     }
 }
 
@@ -353,8 +348,8 @@ void KRslots::showHiddenFiles(bool show)
     KConfigGroup group(krConfig, "Look&Feel");
     group.writeEntry("Show Hidden", show);
 
-    MAIN_VIEW->leftManager()->refreshAllTabs();
-    MAIN_VIEW->rightManager()->refreshAllTabs();
+    MAIN_VIEW->leftManager()->reloadConfig();
+    MAIN_VIEW->rightManager()->reloadConfig();
 }
 
 void KRslots::swapPanels()
@@ -513,7 +508,7 @@ void KRslots::slotSplit()
 
     if (ACTIVE_FUNC->files()->getFileItem(name)->isDir()) {
         KMessageBox::sorry(krApp, i18n("You cannot split a folder."));
-        return ;
+        return;
     }
 
     const QUrl destDir = ACTIVE_PANEL->otherPanel()->virtualPath();
@@ -554,7 +549,7 @@ void KRslots::slotCombine()
 
         if (ACTIVE_FUNC->files()->getFileItem(*it)->isDir()) {
             KMessageBox::sorry(krApp, i18n("You cannot combine a folder."));
-            return ;
+            return;
         }
 
         if (!unixStyle) {
@@ -650,7 +645,9 @@ void KRslots::manageUseractions()
 #ifdef SYNCHRONIZER_ENABLED
 void KRslots::slotSynchronizeDirs(QStringList selected)
 {
-    new SynchronizerGUI(0, LEFT_PANEL->virtualPath(), RIGHT_PANEL->virtualPath(), selected);
+    SynchronizerGUI *synchronizerDialog = new SynchronizerGUI(MAIN_VIEW, LEFT_PANEL->virtualPath(),
+                                                              RIGHT_PANEL->virtualPath(), selected);
+    synchronizerDialog->show(); // destroyed on close
 }
 #endif
 
@@ -681,7 +678,8 @@ void KRslots::execTypeSetup()
 
 void KRslots::slotDiskUsage()
 {
-    DiskUsageGUI du(ACTIVE_PANEL->virtualPath(), MAIN_VIEW);
+    DiskUsageGUI *diskUsageDialog = new DiskUsageGUI(ACTIVE_PANEL->virtualPath());
+    diskUsageDialog->askDirAndShow();
 }
 
 void KRslots::applicationStateChanged()
@@ -710,9 +708,9 @@ void KRslots::emptyTrash()
 void KRslots::trashPopupMenu()
 {
     QMenu trashMenu(krApp);
-    QAction * act = trashMenu.addAction(krLoader->loadIcon("document-open", KIconLoader::Panel), i18n("Open trash bin"));
+    QAction * act = trashMenu.addAction(Icon("document-open"), i18n("Open trash bin"));
     act->setData(QVariant(OPEN_ID));
-    act = trashMenu.addAction(krLoader->loadIcon("trash-empty", KIconLoader::Panel), i18n("Empty trash bin"));
+    act = trashMenu.addAction(Icon("trash-empty"), i18n("Empty trash bin"));
     act->setData(QVariant(EMPTY_TRASH_ID));
 
     int result = -1;
